Class TestResultListResponse.Item
-
- All Implemented Interfaces:
public final class TestResultListResponse.Item
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTestResultListResponse.Item.BuilderA builder for Item.
public final classTestResultListResponse.Item.StatusThe status of the test.
public final classTestResultListResponse.Item.ExpectedValuepublic final classTestResultListResponse.Item.Goalpublic final classTestResultListResponse.Item.RowsBodyThe body of the rows request.
-
Method Summary
Modifier and Type Method Description final Stringid()Project version (commit) id. final OffsetDateTimedateCreated()The creation date. final Optional<OffsetDateTime>dateDataEnds()The data end date. final Optional<OffsetDateTime>dateDataStarts()The data start date. final OffsetDateTimedateUpdated()The last updated date. final Optional<String>inferencePipelineId()The inference pipeline id. final Optional<String>projectVersionId()The project version (commit) id. final TestResultListResponse.Item.Statusstatus()The status of the test. final Optional<String>statusMessage()The status message. final Optional<List<TestResultListResponse.Item.ExpectedValue>>expectedValues()final Optional<TestResultListResponse.Item.Goal>goal()final Optional<String>goalId()The test id. final Optional<String>rows()The URL to the rows of the test result. final Optional<TestResultListResponse.Item.RowsBody>rowsBody()The body of the rows request. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_dateCreated()Returns the raw JSON value of dateCreated. final JsonField<OffsetDateTime>_dateDataEnds()Returns the raw JSON value of dateDataEnds. final JsonField<OffsetDateTime>_dateDataStarts()Returns the raw JSON value of dateDataStarts. final JsonField<OffsetDateTime>_dateUpdated()Returns the raw JSON value of dateUpdated. final JsonField<String>_inferencePipelineId()Returns the raw JSON value of inferencePipelineId. final JsonField<String>_projectVersionId()Returns the raw JSON value of projectVersionId. final JsonField<TestResultListResponse.Item.Status>_status()Returns the raw JSON value of status. final JsonField<String>_statusMessage()Returns the raw JSON value of statusMessage. final JsonField<List<TestResultListResponse.Item.ExpectedValue>>_expectedValues()Returns the raw JSON value of expectedValues. final JsonField<TestResultListResponse.Item.Goal>_goal()Returns the raw JSON value of goal. final JsonField<String>_goalId()Returns the raw JSON value of goalId. final JsonField<String>_rows()Returns the raw JSON value of rows. final JsonField<TestResultListResponse.Item.RowsBody>_rowsBody()Returns the raw JSON value of rowsBody. final Map<String, JsonValue>_additionalProperties()final TestResultListResponse.Item.BuildertoBuilder()final TestResultListResponse.Itemvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TestResultListResponse.Item.Builderbuilder()Returns a mutable builder for constructing an instance of Item. -
-
Method Detail
-
dateCreated
final OffsetDateTime dateCreated()
The creation date.
-
dateDataEnds
final Optional<OffsetDateTime> dateDataEnds()
The data end date.
-
dateDataStarts
final Optional<OffsetDateTime> dateDataStarts()
The data start date.
-
dateUpdated
final OffsetDateTime dateUpdated()
The last updated date.
-
inferencePipelineId
final Optional<String> inferencePipelineId()
The inference pipeline id.
-
projectVersionId
final Optional<String> projectVersionId()
The project version (commit) id.
-
status
final TestResultListResponse.Item.Status status()
The status of the test.
-
statusMessage
final Optional<String> statusMessage()
The status message.
-
expectedValues
final Optional<List<TestResultListResponse.Item.ExpectedValue>> expectedValues()
-
goal
final Optional<TestResultListResponse.Item.Goal> goal()
-
rowsBody
final Optional<TestResultListResponse.Item.RowsBody> rowsBody()
The body of the rows request.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_dateCreated
final JsonField<OffsetDateTime> _dateCreated()
Returns the raw JSON value of dateCreated.
Unlike dateCreated, this method doesn't throw if the JSON field has an unexpected type.
-
_dateDataEnds
final JsonField<OffsetDateTime> _dateDataEnds()
Returns the raw JSON value of dateDataEnds.
Unlike dateDataEnds, this method doesn't throw if the JSON field has an unexpected type.
-
_dateDataStarts
final JsonField<OffsetDateTime> _dateDataStarts()
Returns the raw JSON value of dateDataStarts.
Unlike dateDataStarts, this method doesn't throw if the JSON field has an unexpected type.
-
_dateUpdated
final JsonField<OffsetDateTime> _dateUpdated()
Returns the raw JSON value of dateUpdated.
Unlike dateUpdated, this method doesn't throw if the JSON field has an unexpected type.
-
_inferencePipelineId
final JsonField<String> _inferencePipelineId()
Returns the raw JSON value of inferencePipelineId.
Unlike inferencePipelineId, this method doesn't throw if the JSON field has an unexpected type.
-
_projectVersionId
final JsonField<String> _projectVersionId()
Returns the raw JSON value of projectVersionId.
Unlike projectVersionId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<TestResultListResponse.Item.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_statusMessage
final JsonField<String> _statusMessage()
Returns the raw JSON value of statusMessage.
Unlike statusMessage, this method doesn't throw if the JSON field has an unexpected type.
-
_expectedValues
final JsonField<List<TestResultListResponse.Item.ExpectedValue>> _expectedValues()
Returns the raw JSON value of expectedValues.
Unlike expectedValues, this method doesn't throw if the JSON field has an unexpected type.
-
_goal
final JsonField<TestResultListResponse.Item.Goal> _goal()
Returns the raw JSON value of goal.
Unlike goal, this method doesn't throw if the JSON field has an unexpected type.
-
_goalId
final JsonField<String> _goalId()
Returns the raw JSON value of goalId.
Unlike goalId, this method doesn't throw if the JSON field has an unexpected type.
-
_rows
final JsonField<String> _rows()
Returns the raw JSON value of rows.
Unlike rows, this method doesn't throw if the JSON field has an unexpected type.
-
_rowsBody
final JsonField<TestResultListResponse.Item.RowsBody> _rowsBody()
Returns the raw JSON value of rowsBody.
Unlike rowsBody, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TestResultListResponse.Item.Builder toBuilder()
-
validate
final TestResultListResponse.Item validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TestResultListResponse.Item.Builder builder()
Returns a mutable builder for constructing an instance of Item.
The following fields are required:
.id() .dateCreated() .dateDataEnds() .dateDataStarts() .dateUpdated() .inferencePipelineId() .projectVersionId() .status() .statusMessage()
-
-
-
-