Class TestResultListResponse.Item.Goal
-
- All Implemented Interfaces:
public final class TestResultListResponse.Item.Goal
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTestResultListResponse.Item.Goal.BuilderA builder for Goal.
public final classTestResultListResponse.Item.Goal.SubtypeThe test subtype.
public final classTestResultListResponse.Item.Goal.Thresholdpublic final classTestResultListResponse.Item.Goal.TypeThe test type.
-
Method Summary
Modifier and Type Method Description final Stringid()The test id. final LongcommentCount()The number of comments on the test. final Optional<String>creatorId()The test creator id. final Optional<OffsetDateTime>dateArchived()The date the test was archived. final OffsetDateTimedateCreated()The creation date. final OffsetDateTimedateUpdated()The last updated date. final JsonValue_description()The test description. final Stringname()The test name. final Longnumber()The test number. final Optional<String>originProjectVersionId()The project version (commit) id where the test was created. final TestResultListResponse.Item.Goal.Subtypesubtype()The test subtype. final Booleansuggested()Whether the test is suggested or user-created. final List<TestResultListResponse.Item.Goal.Threshold>thresholds()final TestResultListResponse.Item.Goal.Typetype()The test type. final Optional<Boolean>archived()Whether the test is archived. final Optional<Double>delayWindow()The delay window in seconds. final Optional<Double>evaluationWindow()The evaluation window in seconds. final Optional<Boolean>usesMlModel()Whether the test uses an ML model. final Optional<Boolean>usesProductionData()Whether the test uses production data (monitoring mode only). final Optional<Boolean>usesReferenceDataset()Whether the test uses a reference dataset (monitoring mode only). final Optional<Boolean>usesTrainingDataset()Whether the test uses a training dataset. final Optional<Boolean>usesValidationDataset()Whether the test uses a validation dataset. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Long>_commentCount()Returns the raw JSON value of commentCount. final JsonField<String>_creatorId()Returns the raw JSON value of creatorId. final JsonField<OffsetDateTime>_dateArchived()Returns the raw JSON value of dateArchived. final JsonField<OffsetDateTime>_dateCreated()Returns the raw JSON value of dateCreated. final JsonField<OffsetDateTime>_dateUpdated()Returns the raw JSON value of dateUpdated. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Long>_number()Returns the raw JSON value of number. final JsonField<String>_originProjectVersionId()Returns the raw JSON value of originProjectVersionId. final JsonField<TestResultListResponse.Item.Goal.Subtype>_subtype()Returns the raw JSON value of subtype. final JsonField<Boolean>_suggested()Returns the raw JSON value of suggested. final JsonField<List<TestResultListResponse.Item.Goal.Threshold>>_thresholds()Returns the raw JSON value of thresholds. final JsonField<TestResultListResponse.Item.Goal.Type>_type()Returns the raw JSON value of type. final JsonField<Boolean>_archived()Returns the raw JSON value of archived. final JsonField<Double>_delayWindow()Returns the raw JSON value of delayWindow. final JsonField<Double>_evaluationWindow()Returns the raw JSON value of evaluationWindow. final JsonField<Boolean>_usesMlModel()Returns the raw JSON value of usesMlModel. final JsonField<Boolean>_usesProductionData()Returns the raw JSON value of usesProductionData. final JsonField<Boolean>_usesReferenceDataset()Returns the raw JSON value of usesReferenceDataset. final JsonField<Boolean>_usesTrainingDataset()Returns the raw JSON value of usesTrainingDataset. final JsonField<Boolean>_usesValidationDataset()Returns the raw JSON value of usesValidationDataset. final Map<String, JsonValue>_additionalProperties()final TestResultListResponse.Item.Goal.BuildertoBuilder()final TestResultListResponse.Item.Goalvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TestResultListResponse.Item.Goal.Builderbuilder()Returns a mutable builder for constructing an instance of Goal. -
-
Method Detail
-
commentCount
final Long commentCount()
The number of comments on the test.
-
dateArchived
final Optional<OffsetDateTime> dateArchived()
The date the test was archived.
-
dateCreated
final OffsetDateTime dateCreated()
The creation date.
-
dateUpdated
final OffsetDateTime dateUpdated()
The last updated date.
-
_description
final JsonValue _description()
The test description.
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = goal.description().convert(MyClass.class);
-
originProjectVersionId
final Optional<String> originProjectVersionId()
The project version (commit) id where the test was created.
-
subtype
final TestResultListResponse.Item.Goal.Subtype subtype()
The test subtype.
-
thresholds
final List<TestResultListResponse.Item.Goal.Threshold> thresholds()
-
type
final TestResultListResponse.Item.Goal.Type type()
The test type.
-
delayWindow
final Optional<Double> delayWindow()
The delay window in seconds. Only applies to tests that use production data.
-
evaluationWindow
final Optional<Double> evaluationWindow()
The evaluation window in seconds. Only applies to tests that use production data.
-
usesMlModel
final Optional<Boolean> usesMlModel()
Whether the test uses an ML model.
-
usesProductionData
final Optional<Boolean> usesProductionData()
Whether the test uses production data (monitoring mode only).
-
usesReferenceDataset
final Optional<Boolean> usesReferenceDataset()
Whether the test uses a reference dataset (monitoring mode only).
-
usesTrainingDataset
final Optional<Boolean> usesTrainingDataset()
Whether the test uses a training dataset.
-
usesValidationDataset
final Optional<Boolean> usesValidationDataset()
Whether the test uses a validation dataset.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_commentCount
final JsonField<Long> _commentCount()
Returns the raw JSON value of commentCount.
Unlike commentCount, this method doesn't throw if the JSON field has an unexpected type.
-
_creatorId
final JsonField<String> _creatorId()
Returns the raw JSON value of creatorId.
Unlike creatorId, this method doesn't throw if the JSON field has an unexpected type.
-
_dateArchived
final JsonField<OffsetDateTime> _dateArchived()
Returns the raw JSON value of dateArchived.
Unlike dateArchived, this method doesn't throw if the JSON field has an unexpected type.
-
_dateCreated
final JsonField<OffsetDateTime> _dateCreated()
Returns the raw JSON value of dateCreated.
Unlike dateCreated, this method doesn't throw if the JSON field has an unexpected type.
-
_dateUpdated
final JsonField<OffsetDateTime> _dateUpdated()
Returns the raw JSON value of dateUpdated.
Unlike dateUpdated, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_number
final JsonField<Long> _number()
Returns the raw JSON value of number.
Unlike number, this method doesn't throw if the JSON field has an unexpected type.
-
_originProjectVersionId
final JsonField<String> _originProjectVersionId()
Returns the raw JSON value of originProjectVersionId.
Unlike originProjectVersionId, this method doesn't throw if the JSON field has an unexpected type.
-
_subtype
final JsonField<TestResultListResponse.Item.Goal.Subtype> _subtype()
Returns the raw JSON value of subtype.
Unlike subtype, this method doesn't throw if the JSON field has an unexpected type.
-
_suggested
final JsonField<Boolean> _suggested()
Returns the raw JSON value of suggested.
Unlike suggested, this method doesn't throw if the JSON field has an unexpected type.
-
_thresholds
final JsonField<List<TestResultListResponse.Item.Goal.Threshold>> _thresholds()
Returns the raw JSON value of thresholds.
Unlike thresholds, this method doesn't throw if the JSON field has an unexpected type.
-
_type
final JsonField<TestResultListResponse.Item.Goal.Type> _type()
Returns the raw JSON value of type.
Unlike type, this method doesn't throw if the JSON field has an unexpected type.
-
_archived
final JsonField<Boolean> _archived()
Returns the raw JSON value of archived.
Unlike archived, this method doesn't throw if the JSON field has an unexpected type.
-
_delayWindow
final JsonField<Double> _delayWindow()
Returns the raw JSON value of delayWindow.
Unlike delayWindow, this method doesn't throw if the JSON field has an unexpected type.
-
_evaluationWindow
final JsonField<Double> _evaluationWindow()
Returns the raw JSON value of evaluationWindow.
Unlike evaluationWindow, this method doesn't throw if the JSON field has an unexpected type.
-
_usesMlModel
final JsonField<Boolean> _usesMlModel()
Returns the raw JSON value of usesMlModel.
Unlike usesMlModel, this method doesn't throw if the JSON field has an unexpected type.
-
_usesProductionData
final JsonField<Boolean> _usesProductionData()
Returns the raw JSON value of usesProductionData.
Unlike usesProductionData, this method doesn't throw if the JSON field has an unexpected type.
-
_usesReferenceDataset
final JsonField<Boolean> _usesReferenceDataset()
Returns the raw JSON value of usesReferenceDataset.
Unlike usesReferenceDataset, this method doesn't throw if the JSON field has an unexpected type.
-
_usesTrainingDataset
final JsonField<Boolean> _usesTrainingDataset()
Returns the raw JSON value of usesTrainingDataset.
Unlike usesTrainingDataset, this method doesn't throw if the JSON field has an unexpected type.
-
_usesValidationDataset
final JsonField<Boolean> _usesValidationDataset()
Returns the raw JSON value of usesValidationDataset.
Unlike usesValidationDataset, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TestResultListResponse.Item.Goal.Builder toBuilder()
-
validate
final TestResultListResponse.Item.Goal validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TestResultListResponse.Item.Goal.Builder builder()
Returns a mutable builder for constructing an instance of Goal.
The following fields are required:
.id() .commentCount() .creatorId() .dateArchived() .dateCreated() .dateUpdated() .description() .name() .number() .originProjectVersionId() .subtype() .suggested() .thresholds() .type()
-
-
-
-