Class InferencePipelineRetrieveResponse.DataBackend.DatabricksDtlDataBackend
-
- All Implemented Interfaces:
public final class InferencePipelineRetrieveResponse.DataBackend.DatabricksDtlDataBackend
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineRetrieveResponse.DataBackend.DatabricksDtlDataBackend.BuilderA builder for DatabricksDtlDataBackend.
public final classInferencePipelineRetrieveResponse.DataBackend.DatabricksDtlDataBackend.BackendTypepublic final classInferencePipelineRetrieveResponse.DataBackend.DatabricksDtlDataBackend.Config
-
Method Summary
-
-
Method Detail
-
backendType
final InferencePipelineRetrieveResponse.DataBackend.DatabricksDtlDataBackend.BackendType backendType()
-
databricksDtlConnectionId
final Optional<String> databricksDtlConnectionId()
-
_backendType
final JsonField<InferencePipelineRetrieveResponse.DataBackend.DatabricksDtlDataBackend.BackendType> _backendType()
Returns the raw JSON value of backendType.
Unlike backendType, this method doesn't throw if the JSON field has an unexpected type.
-
_config
final JsonField<InferencePipelineRetrieveResponse.DataBackend.DatabricksDtlDataBackend.Config> _config()
Returns the raw JSON value of config.
Unlike config, this method doesn't throw if the JSON field has an unexpected type.
-
_databricksDtlConnectionId
final JsonField<String> _databricksDtlConnectionId()
Returns the raw JSON value of databricksDtlConnectionId.
Unlike databricksDtlConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_tableId
final JsonField<String> _tableId()
Returns the raw JSON value of tableId.
Unlike tableId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineRetrieveResponse.DataBackend.DatabricksDtlDataBackend.Builder toBuilder()
-
validate
final InferencePipelineRetrieveResponse.DataBackend.DatabricksDtlDataBackend validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineRetrieveResponse.DataBackend.DatabricksDtlDataBackend.Builder builder()
Returns a mutable builder for constructing an instance of DatabricksDtlDataBackend.
The following fields are required:
.backendType() .config() .databricksDtlConnectionId() .tableId()
-
-
-
-