Class InferencePipelineRetrieveResponse.DataBackend.DefaultDataBackend
-
- All Implemented Interfaces:
public final class InferencePipelineRetrieveResponse.DataBackend.DefaultDataBackend
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineRetrieveResponse.DataBackend.DefaultDataBackend.BuilderA builder for DefaultDataBackend.
public final classInferencePipelineRetrieveResponse.DataBackend.DefaultDataBackend.BackendType
-
Method Summary
Modifier and Type Method Description final InferencePipelineRetrieveResponse.DataBackend.DefaultDataBackend.BackendTypebackendType()final JsonField<InferencePipelineRetrieveResponse.DataBackend.DefaultDataBackend.BackendType>_backendType()Returns the raw JSON value of backendType. final Map<String, JsonValue>_additionalProperties()final InferencePipelineRetrieveResponse.DataBackend.DefaultDataBackend.BuildertoBuilder()final InferencePipelineRetrieveResponse.DataBackend.DefaultDataBackendvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InferencePipelineRetrieveResponse.DataBackend.DefaultDataBackend.Builderbuilder()Returns a mutable builder for constructing an instance of DefaultDataBackend. -
-
Method Detail
-
backendType
final InferencePipelineRetrieveResponse.DataBackend.DefaultDataBackend.BackendType backendType()
-
_backendType
final JsonField<InferencePipelineRetrieveResponse.DataBackend.DefaultDataBackend.BackendType> _backendType()
Returns the raw JSON value of backendType.
Unlike backendType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineRetrieveResponse.DataBackend.DefaultDataBackend.Builder toBuilder()
-
validate
final InferencePipelineRetrieveResponse.DataBackend.DefaultDataBackend validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineRetrieveResponse.DataBackend.DefaultDataBackend.Builder builder()
Returns a mutable builder for constructing an instance of DefaultDataBackend.
The following fields are required:
.backendType()
-
-
-
-