Class InferencePipelineRetrieveResponse.DataBackend.PostgresDataBackend
-
- All Implemented Interfaces:
public final class InferencePipelineRetrieveResponse.DataBackend.PostgresDataBackend
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineRetrieveResponse.DataBackend.PostgresDataBackend.BuilderA builder for PostgresDataBackend.
public final classInferencePipelineRetrieveResponse.DataBackend.PostgresDataBackend.BackendTypepublic final classInferencePipelineRetrieveResponse.DataBackend.PostgresDataBackend.Config
-
Method Summary
-
-
Method Detail
-
backendType
final InferencePipelineRetrieveResponse.DataBackend.PostgresDataBackend.BackendType backendType()
-
postgresConnectionId
final Optional<String> postgresConnectionId()
-
_backendType
final JsonField<InferencePipelineRetrieveResponse.DataBackend.PostgresDataBackend.BackendType> _backendType()
Returns the raw JSON value of backendType.
Unlike backendType, this method doesn't throw if the JSON field has an unexpected type.
-
_config
final JsonField<InferencePipelineRetrieveResponse.DataBackend.PostgresDataBackend.Config> _config()
Returns the raw JSON value of config.
Unlike config, this method doesn't throw if the JSON field has an unexpected type.
-
_database
final JsonField<String> _database()
Returns the raw JSON value of database.
Unlike database, this method doesn't throw if the JSON field has an unexpected type.
-
_postgresConnectionId
final JsonField<String> _postgresConnectionId()
Returns the raw JSON value of postgresConnectionId.
Unlike postgresConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_schema
final JsonField<String> _schema()
Returns the raw JSON value of schema.
Unlike schema, this method doesn't throw if the JSON field has an unexpected type.
-
_table
final JsonField<String> _table()
Returns the raw JSON value of table.
Unlike table, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineRetrieveResponse.DataBackend.PostgresDataBackend.Builder toBuilder()
-
validate
final InferencePipelineRetrieveResponse.DataBackend.PostgresDataBackend validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineRetrieveResponse.DataBackend.PostgresDataBackend.Builder builder()
Returns a mutable builder for constructing an instance of PostgresDataBackend.
The following fields are required:
.backendType() .config() .database() .postgresConnectionId() .schema() .table()
-
-
-
-