Class InferencePipelineRetrieveResponse.DataBackend.SnowflakeDataBackend
-
- All Implemented Interfaces:
public final class InferencePipelineRetrieveResponse.DataBackend.SnowflakeDataBackend
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineRetrieveResponse.DataBackend.SnowflakeDataBackend.BuilderA builder for SnowflakeDataBackend.
public final classInferencePipelineRetrieveResponse.DataBackend.SnowflakeDataBackend.BackendTypepublic final classInferencePipelineRetrieveResponse.DataBackend.SnowflakeDataBackend.Config
-
Method Summary
-
-
Method Detail
-
backendType
final InferencePipelineRetrieveResponse.DataBackend.SnowflakeDataBackend.BackendType backendType()
-
snowflakeConnectionId
final Optional<String> snowflakeConnectionId()
-
_backendType
final JsonField<InferencePipelineRetrieveResponse.DataBackend.SnowflakeDataBackend.BackendType> _backendType()
Returns the raw JSON value of backendType.
Unlike backendType, this method doesn't throw if the JSON field has an unexpected type.
-
_config
final JsonField<InferencePipelineRetrieveResponse.DataBackend.SnowflakeDataBackend.Config> _config()
Returns the raw JSON value of config.
Unlike config, this method doesn't throw if the JSON field has an unexpected type.
-
_database
final JsonField<String> _database()
Returns the raw JSON value of database.
Unlike database, this method doesn't throw if the JSON field has an unexpected type.
-
_schema
final JsonField<String> _schema()
Returns the raw JSON value of schema.
Unlike schema, this method doesn't throw if the JSON field has an unexpected type.
-
_snowflakeConnectionId
final JsonField<String> _snowflakeConnectionId()
Returns the raw JSON value of snowflakeConnectionId.
Unlike snowflakeConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_table
final JsonField<String> _table()
Returns the raw JSON value of table.
Unlike table, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineRetrieveResponse.DataBackend.SnowflakeDataBackend.Builder toBuilder()
-
validate
final InferencePipelineRetrieveResponse.DataBackend.SnowflakeDataBackend validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineRetrieveResponse.DataBackend.SnowflakeDataBackend.Builder builder()
Returns a mutable builder for constructing an instance of SnowflakeDataBackend.
The following fields are required:
.backendType() .config() .database() .schema() .snowflakeConnectionId() .table()
-
-
-
-