Class InferencePipelineRetrieveResponse.DataBackend.UnionMember3
-
- All Implemented Interfaces:
public final class InferencePipelineRetrieveResponse.DataBackend.UnionMember3
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineRetrieveResponse.DataBackend.UnionMember3.BuilderA builder for UnionMember3.
public final classInferencePipelineRetrieveResponse.DataBackend.UnionMember3.BackendTypepublic final classInferencePipelineRetrieveResponse.DataBackend.UnionMember3.Config
-
Method Summary
-
-
Method Detail
-
backendType
final InferencePipelineRetrieveResponse.DataBackend.UnionMember3.BackendType backendType()
-
databricksDtlConnectionId
final Optional<String> databricksDtlConnectionId()
-
_backendType
final JsonField<InferencePipelineRetrieveResponse.DataBackend.UnionMember3.BackendType> _backendType()
Returns the raw JSON value of backendType.
Unlike backendType, this method doesn't throw if the JSON field has an unexpected type.
-
_config
final JsonField<InferencePipelineRetrieveResponse.DataBackend.UnionMember3.Config> _config()
Returns the raw JSON value of config.
Unlike config, this method doesn't throw if the JSON field has an unexpected type.
-
_databricksDtlConnectionId
final JsonField<String> _databricksDtlConnectionId()
Returns the raw JSON value of databricksDtlConnectionId.
Unlike databricksDtlConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_tableId
final JsonField<String> _tableId()
Returns the raw JSON value of tableId.
Unlike tableId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineRetrieveResponse.DataBackend.UnionMember3.Builder toBuilder()
-
validate
final InferencePipelineRetrieveResponse.DataBackend.UnionMember3 validate()
-
builder
final static InferencePipelineRetrieveResponse.DataBackend.UnionMember3.Builder builder()
Returns a mutable builder for constructing an instance of UnionMember3.
The following fields are required:
.backendType() .config() .databricksDtlConnectionId() .tableId()
-
-
-
-