Class InferencePipelineRetrieveSessionsParams

  • All Implemented Interfaces:
    com.openlayer.api.core.Params

    
    public final class InferencePipelineRetrieveSessionsParams
     implements Params
                        

    Get aggregated session data for an inference pipeline with pagination and metadata.

    Returns a list of sessions for the inference pipeline, including activity statistics such as record counts, token usage, cost, latency, and the first and last records.