Class InferencePipelineRetrieveSessionsResponse.Item
-
- All Implemented Interfaces:
public final class InferencePipelineRetrieveSessionsResponse.Item
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineRetrieveSessionsResponse.Item.BuilderA builder for Item.
public final classInferencePipelineRetrieveSessionsResponse.Item.FirstRecordThe complete first record in the session
public final classInferencePipelineRetrieveSessionsResponse.Item.LastRecordThe complete last record in the session
-
Method Summary
Modifier and Type Method Description final Stringid()The unique session identifier final Floatcost()Total cost for the session final OffsetDateTimedateCreated()Latest/most recent timestamp in the session final OffsetDateTimedateOfFirstRecord()Timestamp of the first request in the session final OffsetDateTimedateOfLastRecord()Timestamp of the last request in the session final Floatduration()Duration between first and last request (in milliseconds) final InferencePipelineRetrieveSessionsResponse.Item.FirstRecordfirstRecord()The complete first record in the session final InferencePipelineRetrieveSessionsResponse.Item.LastRecordlastRecord()The complete last record in the session final Floatlatency()Total latency for the session (in milliseconds) final Longrecords()Total number of records/traces in the session final Floattokens()Total token count for the session final List<String>userIds()List of unique user IDs that participated in this session final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Float>_cost()Returns the raw JSON value of cost. final JsonField<OffsetDateTime>_dateCreated()Returns the raw JSON value of dateCreated. final JsonField<OffsetDateTime>_dateOfFirstRecord()Returns the raw JSON value of dateOfFirstRecord. final JsonField<OffsetDateTime>_dateOfLastRecord()Returns the raw JSON value of dateOfLastRecord. final JsonField<Float>_duration()Returns the raw JSON value of duration. final JsonField<InferencePipelineRetrieveSessionsResponse.Item.FirstRecord>_firstRecord()Returns the raw JSON value of firstRecord. final JsonField<InferencePipelineRetrieveSessionsResponse.Item.LastRecord>_lastRecord()Returns the raw JSON value of lastRecord. final JsonField<Float>_latency()Returns the raw JSON value of latency. final JsonField<Long>_records()Returns the raw JSON value of records. final JsonField<Float>_tokens()Returns the raw JSON value of tokens. final JsonField<List<String>>_userIds()Returns the raw JSON value of userIds. final Map<String, JsonValue>_additionalProperties()final InferencePipelineRetrieveSessionsResponse.Item.BuildertoBuilder()final InferencePipelineRetrieveSessionsResponse.Itemvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InferencePipelineRetrieveSessionsResponse.Item.Builderbuilder()Returns a mutable builder for constructing an instance of Item. -
-
Method Detail
-
dateCreated
final OffsetDateTime dateCreated()
Latest/most recent timestamp in the session
-
dateOfFirstRecord
final OffsetDateTime dateOfFirstRecord()
Timestamp of the first request in the session
-
dateOfLastRecord
final OffsetDateTime dateOfLastRecord()
Timestamp of the last request in the session
-
firstRecord
final InferencePipelineRetrieveSessionsResponse.Item.FirstRecord firstRecord()
The complete first record in the session
-
lastRecord
final InferencePipelineRetrieveSessionsResponse.Item.LastRecord lastRecord()
The complete last record in the session
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_cost
final JsonField<Float> _cost()
Returns the raw JSON value of cost.
Unlike cost, this method doesn't throw if the JSON field has an unexpected type.
-
_dateCreated
final JsonField<OffsetDateTime> _dateCreated()
Returns the raw JSON value of dateCreated.
Unlike dateCreated, this method doesn't throw if the JSON field has an unexpected type.
-
_dateOfFirstRecord
final JsonField<OffsetDateTime> _dateOfFirstRecord()
Returns the raw JSON value of dateOfFirstRecord.
Unlike dateOfFirstRecord, this method doesn't throw if the JSON field has an unexpected type.
-
_dateOfLastRecord
final JsonField<OffsetDateTime> _dateOfLastRecord()
Returns the raw JSON value of dateOfLastRecord.
Unlike dateOfLastRecord, this method doesn't throw if the JSON field has an unexpected type.
-
_duration
final JsonField<Float> _duration()
Returns the raw JSON value of duration.
Unlike duration, this method doesn't throw if the JSON field has an unexpected type.
-
_firstRecord
final JsonField<InferencePipelineRetrieveSessionsResponse.Item.FirstRecord> _firstRecord()
Returns the raw JSON value of firstRecord.
Unlike firstRecord, this method doesn't throw if the JSON field has an unexpected type.
-
_lastRecord
final JsonField<InferencePipelineRetrieveSessionsResponse.Item.LastRecord> _lastRecord()
Returns the raw JSON value of lastRecord.
Unlike lastRecord, this method doesn't throw if the JSON field has an unexpected type.
-
_latency
final JsonField<Float> _latency()
Returns the raw JSON value of latency.
Unlike latency, this method doesn't throw if the JSON field has an unexpected type.
-
_records
final JsonField<Long> _records()
Returns the raw JSON value of records.
Unlike records, this method doesn't throw if the JSON field has an unexpected type.
-
_tokens
final JsonField<Float> _tokens()
Returns the raw JSON value of tokens.
Unlike tokens, this method doesn't throw if the JSON field has an unexpected type.
-
_userIds
final JsonField<List<String>> _userIds()
Returns the raw JSON value of userIds.
Unlike userIds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineRetrieveSessionsResponse.Item.Builder toBuilder()
-
validate
final InferencePipelineRetrieveSessionsResponse.Item validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineRetrieveSessionsResponse.Item.Builder builder()
Returns a mutable builder for constructing an instance of Item.
The following fields are required:
.id() .cost() .dateCreated() .dateOfFirstRecord() .dateOfLastRecord() .duration() .firstRecord() .lastRecord() .latency() .records() .tokens() .userIds()
-
-
-
-