Class InferencePipelineRetrieveUsersParams

  • All Implemented Interfaces:
    com.openlayer.api.core.Params

    
    public final class InferencePipelineRetrieveUsersParams
     implements Params
                        

    Get aggregated user data for an inference pipeline with pagination and metadata.

    Returns a list of users who have interacted with the inference pipeline, including their activity statistics such as session counts, record counts, token usage, and costs.