Class InferencePipelineRetrieveUsersParams.Body
-
- All Implemented Interfaces:
public final class InferencePipelineRetrieveUsersParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineRetrieveUsersParams.Body.BuilderA builder for Body.
-
Method Summary
-
-
Method Detail
-
columnFilters
final Optional<List<InferencePipelineRetrieveUsersParams.ColumnFilter>> columnFilters()
-
excludeRowIdList
final Optional<List<Long>> excludeRowIdList()
-
notSearchQueryAnd
final Optional<List<String>> notSearchQueryAnd()
-
notSearchQueryOr
final Optional<List<String>> notSearchQueryOr()
-
searchQueryAnd
final Optional<List<String>> searchQueryAnd()
-
searchQueryOr
final Optional<List<String>> searchQueryOr()
-
_columnFilters
final JsonField<List<InferencePipelineRetrieveUsersParams.ColumnFilter>> _columnFilters()
Returns the raw JSON value of columnFilters.
Unlike columnFilters, this method doesn't throw if the JSON field has an unexpected type.
-
_excludeRowIdList
final JsonField<List<Long>> _excludeRowIdList()
Returns the raw JSON value of excludeRowIdList.
Unlike excludeRowIdList, this method doesn't throw if the JSON field has an unexpected type.
-
_notSearchQueryAnd
final JsonField<List<String>> _notSearchQueryAnd()
Returns the raw JSON value of notSearchQueryAnd.
Unlike notSearchQueryAnd, this method doesn't throw if the JSON field has an unexpected type.
-
_notSearchQueryOr
final JsonField<List<String>> _notSearchQueryOr()
Returns the raw JSON value of notSearchQueryOr.
Unlike notSearchQueryOr, this method doesn't throw if the JSON field has an unexpected type.
-
_rowIdList
final JsonField<List<Long>> _rowIdList()
Returns the raw JSON value of rowIdList.
Unlike rowIdList, this method doesn't throw if the JSON field has an unexpected type.
-
_searchQueryAnd
final JsonField<List<String>> _searchQueryAnd()
Returns the raw JSON value of searchQueryAnd.
Unlike searchQueryAnd, this method doesn't throw if the JSON field has an unexpected type.
-
_searchQueryOr
final JsonField<List<String>> _searchQueryOr()
Returns the raw JSON value of searchQueryOr.
Unlike searchQueryOr, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineRetrieveUsersParams.Body.Builder toBuilder()
-
validate
final InferencePipelineRetrieveUsersParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineRetrieveUsersParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-