Class InferencePipelineRetrieveUsersResponse.Item
-
- All Implemented Interfaces:
public final class InferencePipelineRetrieveUsersResponse.Item
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineRetrieveUsersResponse.Item.BuilderA builder for Item.
-
Method Summary
Modifier and Type Method Description final Stringid()The unique user identifier final Floatcost()Total cost for this user final OffsetDateTimedateOfFirstRecord()Timestamp of the user's first event/trace final OffsetDateTimedateOfLastRecord()Timestamp of the user's last event/trace final Longrecords()Total number of traces/rows for this user final Longsessions()Count of unique sessions for this user final Floattokens()Total token count for this user final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Float>_cost()Returns the raw JSON value of cost. final JsonField<OffsetDateTime>_dateOfFirstRecord()Returns the raw JSON value of dateOfFirstRecord. final JsonField<OffsetDateTime>_dateOfLastRecord()Returns the raw JSON value of dateOfLastRecord. final JsonField<Long>_records()Returns the raw JSON value of records. final JsonField<Long>_sessions()Returns the raw JSON value of sessions. final JsonField<Float>_tokens()Returns the raw JSON value of tokens. final Map<String, JsonValue>_additionalProperties()final InferencePipelineRetrieveUsersResponse.Item.BuildertoBuilder()final InferencePipelineRetrieveUsersResponse.Itemvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InferencePipelineRetrieveUsersResponse.Item.Builderbuilder()Returns a mutable builder for constructing an instance of Item. -
-
Method Detail
-
dateOfFirstRecord
final OffsetDateTime dateOfFirstRecord()
Timestamp of the user's first event/trace
-
dateOfLastRecord
final OffsetDateTime dateOfLastRecord()
Timestamp of the user's last event/trace
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_cost
final JsonField<Float> _cost()
Returns the raw JSON value of cost.
Unlike cost, this method doesn't throw if the JSON field has an unexpected type.
-
_dateOfFirstRecord
final JsonField<OffsetDateTime> _dateOfFirstRecord()
Returns the raw JSON value of dateOfFirstRecord.
Unlike dateOfFirstRecord, this method doesn't throw if the JSON field has an unexpected type.
-
_dateOfLastRecord
final JsonField<OffsetDateTime> _dateOfLastRecord()
Returns the raw JSON value of dateOfLastRecord.
Unlike dateOfLastRecord, this method doesn't throw if the JSON field has an unexpected type.
-
_records
final JsonField<Long> _records()
Returns the raw JSON value of records.
Unlike records, this method doesn't throw if the JSON field has an unexpected type.
-
_sessions
final JsonField<Long> _sessions()
Returns the raw JSON value of sessions.
Unlike sessions, this method doesn't throw if the JSON field has an unexpected type.
-
_tokens
final JsonField<Float> _tokens()
Returns the raw JSON value of tokens.
Unlike tokens, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineRetrieveUsersResponse.Item.Builder toBuilder()
-
validate
final InferencePipelineRetrieveUsersResponse.Item validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineRetrieveUsersResponse.Item.Builder builder()
Returns a mutable builder for constructing an instance of Item.
The following fields are required:
.id() .cost() .dateOfFirstRecord() .dateOfLastRecord() .records() .sessions() .tokens()
-
-
-
-