Class InferencePipelineUpdateParams.Body
-
- All Implemented Interfaces:
public final class InferencePipelineUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>description()The inference pipeline description. final Optional<String>name()The inference pipeline name. final Optional<String>referenceDatasetUri()The storage uri of your reference dataset. final JsonField<String>_description()Returns the raw JSON value of description. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_referenceDatasetUri()Returns the raw JSON value of referenceDatasetUri. final Map<String, JsonValue>_additionalProperties()final InferencePipelineUpdateParams.Body.BuildertoBuilder()final InferencePipelineUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InferencePipelineUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
description
final Optional<String> description()
The inference pipeline description.
-
referenceDatasetUri
final Optional<String> referenceDatasetUri()
The storage uri of your reference dataset. We recommend using the Python SDK or the UI to handle your reference dataset updates.
-
_description
final JsonField<String> _description()
Returns the raw JSON value of description.
Unlike description, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_referenceDatasetUri
final JsonField<String> _referenceDatasetUri()
Returns the raw JSON value of referenceDatasetUri.
Unlike referenceDatasetUri, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineUpdateParams.Body.Builder toBuilder()
-
validate
final InferencePipelineUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-