Class InferencePipelineUpdateResponse.DataBackend.BigQueryDataBackend
-
- All Implemented Interfaces:
public final class InferencePipelineUpdateResponse.DataBackend.BigQueryDataBackend
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineUpdateResponse.DataBackend.BigQueryDataBackend.BuilderA builder for BigQueryDataBackend.
public final classInferencePipelineUpdateResponse.DataBackend.BigQueryDataBackend.BackendTypepublic final classInferencePipelineUpdateResponse.DataBackend.BigQueryDataBackend.Configpublic final classInferencePipelineUpdateResponse.DataBackend.BigQueryDataBackend.PartitionType
-
Method Summary
-
-
Method Detail
-
backendType
final InferencePipelineUpdateResponse.DataBackend.BigQueryDataBackend.BackendType backendType()
-
bigqueryConnectionId
final Optional<String> bigqueryConnectionId()
-
partitionType
final Optional<InferencePipelineUpdateResponse.DataBackend.BigQueryDataBackend.PartitionType> partitionType()
-
_backendType
final JsonField<InferencePipelineUpdateResponse.DataBackend.BigQueryDataBackend.BackendType> _backendType()
Returns the raw JSON value of backendType.
Unlike backendType, this method doesn't throw if the JSON field has an unexpected type.
-
_bigqueryConnectionId
final JsonField<String> _bigqueryConnectionId()
Returns the raw JSON value of bigqueryConnectionId.
Unlike bigqueryConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_config
final JsonField<InferencePipelineUpdateResponse.DataBackend.BigQueryDataBackend.Config> _config()
Returns the raw JSON value of config.
Unlike config, this method doesn't throw if the JSON field has an unexpected type.
-
_datasetId
final JsonField<String> _datasetId()
Returns the raw JSON value of datasetId.
Unlike datasetId, this method doesn't throw if the JSON field has an unexpected type.
-
_projectId
final JsonField<String> _projectId()
Returns the raw JSON value of projectId.
Unlike projectId, this method doesn't throw if the JSON field has an unexpected type.
-
_tableId
final JsonField<String> _tableId()
Returns the raw JSON value of tableId.
Unlike tableId, this method doesn't throw if the JSON field has an unexpected type.
-
_partitionType
final JsonField<InferencePipelineUpdateResponse.DataBackend.BigQueryDataBackend.PartitionType> _partitionType()
Returns the raw JSON value of partitionType.
Unlike partitionType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InferencePipelineUpdateResponse.DataBackend.BigQueryDataBackend validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineUpdateResponse.DataBackend.BigQueryDataBackend.Builder builder()
Returns a mutable builder for constructing an instance of BigQueryDataBackend.
The following fields are required:
.backendType() .bigqueryConnectionId() .config() .datasetId() .projectId() .tableId()
-
-
-
-