Class InferencePipelineUpdateResponse.DataBackend.DatabricksDtlDataBackend
-
- All Implemented Interfaces:
public final class InferencePipelineUpdateResponse.DataBackend.DatabricksDtlDataBackend
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineUpdateResponse.DataBackend.DatabricksDtlDataBackend.BuilderA builder for DatabricksDtlDataBackend.
public final classInferencePipelineUpdateResponse.DataBackend.DatabricksDtlDataBackend.BackendTypepublic final classInferencePipelineUpdateResponse.DataBackend.DatabricksDtlDataBackend.Config
-
Method Summary
-
-
Method Detail
-
backendType
final InferencePipelineUpdateResponse.DataBackend.DatabricksDtlDataBackend.BackendType backendType()
-
databricksDtlConnectionId
final Optional<String> databricksDtlConnectionId()
-
_backendType
final JsonField<InferencePipelineUpdateResponse.DataBackend.DatabricksDtlDataBackend.BackendType> _backendType()
Returns the raw JSON value of backendType.
Unlike backendType, this method doesn't throw if the JSON field has an unexpected type.
-
_config
final JsonField<InferencePipelineUpdateResponse.DataBackend.DatabricksDtlDataBackend.Config> _config()
Returns the raw JSON value of config.
Unlike config, this method doesn't throw if the JSON field has an unexpected type.
-
_databricksDtlConnectionId
final JsonField<String> _databricksDtlConnectionId()
Returns the raw JSON value of databricksDtlConnectionId.
Unlike databricksDtlConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_tableId
final JsonField<String> _tableId()
Returns the raw JSON value of tableId.
Unlike tableId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineUpdateResponse.DataBackend.DatabricksDtlDataBackend.Builder toBuilder()
-
validate
final InferencePipelineUpdateResponse.DataBackend.DatabricksDtlDataBackend validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineUpdateResponse.DataBackend.DatabricksDtlDataBackend.Builder builder()
Returns a mutable builder for constructing an instance of DatabricksDtlDataBackend.
The following fields are required:
.backendType() .config() .databricksDtlConnectionId() .tableId()
-
-
-
-