Class InferencePipelineUpdateResponse.DataBackend.DefaultDataBackend
-
- All Implemented Interfaces:
public final class InferencePipelineUpdateResponse.DataBackend.DefaultDataBackend
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineUpdateResponse.DataBackend.DefaultDataBackend.BuilderA builder for DefaultDataBackend.
public final classInferencePipelineUpdateResponse.DataBackend.DefaultDataBackend.BackendType
-
Method Summary
Modifier and Type Method Description final InferencePipelineUpdateResponse.DataBackend.DefaultDataBackend.BackendTypebackendType()final JsonField<InferencePipelineUpdateResponse.DataBackend.DefaultDataBackend.BackendType>_backendType()Returns the raw JSON value of backendType. final Map<String, JsonValue>_additionalProperties()final InferencePipelineUpdateResponse.DataBackend.DefaultDataBackend.BuildertoBuilder()final InferencePipelineUpdateResponse.DataBackend.DefaultDataBackendvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InferencePipelineUpdateResponse.DataBackend.DefaultDataBackend.Builderbuilder()Returns a mutable builder for constructing an instance of DefaultDataBackend. -
-
Method Detail
-
backendType
final InferencePipelineUpdateResponse.DataBackend.DefaultDataBackend.BackendType backendType()
-
_backendType
final JsonField<InferencePipelineUpdateResponse.DataBackend.DefaultDataBackend.BackendType> _backendType()
Returns the raw JSON value of backendType.
Unlike backendType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InferencePipelineUpdateResponse.DataBackend.DefaultDataBackend validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineUpdateResponse.DataBackend.DefaultDataBackend.Builder builder()
Returns a mutable builder for constructing an instance of DefaultDataBackend.
The following fields are required:
.backendType()
-
-
-
-