Class InferencePipelineUpdateResponse.DataBackend.SnowflakeDataBackend
-
- All Implemented Interfaces:
public final class InferencePipelineUpdateResponse.DataBackend.SnowflakeDataBackend
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineUpdateResponse.DataBackend.SnowflakeDataBackend.BuilderA builder for SnowflakeDataBackend.
public final classInferencePipelineUpdateResponse.DataBackend.SnowflakeDataBackend.BackendTypepublic final classInferencePipelineUpdateResponse.DataBackend.SnowflakeDataBackend.Config
-
Method Summary
-
-
Method Detail
-
backendType
final InferencePipelineUpdateResponse.DataBackend.SnowflakeDataBackend.BackendType backendType()
-
snowflakeConnectionId
final Optional<String> snowflakeConnectionId()
-
_backendType
final JsonField<InferencePipelineUpdateResponse.DataBackend.SnowflakeDataBackend.BackendType> _backendType()
Returns the raw JSON value of backendType.
Unlike backendType, this method doesn't throw if the JSON field has an unexpected type.
-
_config
final JsonField<InferencePipelineUpdateResponse.DataBackend.SnowflakeDataBackend.Config> _config()
Returns the raw JSON value of config.
Unlike config, this method doesn't throw if the JSON field has an unexpected type.
-
_database
final JsonField<String> _database()
Returns the raw JSON value of database.
Unlike database, this method doesn't throw if the JSON field has an unexpected type.
-
_schema
final JsonField<String> _schema()
Returns the raw JSON value of schema.
Unlike schema, this method doesn't throw if the JSON field has an unexpected type.
-
_snowflakeConnectionId
final JsonField<String> _snowflakeConnectionId()
Returns the raw JSON value of snowflakeConnectionId.
Unlike snowflakeConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_table
final JsonField<String> _table()
Returns the raw JSON value of table.
Unlike table, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineUpdateResponse.DataBackend.SnowflakeDataBackend.Builder toBuilder()
-
validate
final InferencePipelineUpdateResponse.DataBackend.SnowflakeDataBackend validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineUpdateResponse.DataBackend.SnowflakeDataBackend.Builder builder()
Returns a mutable builder for constructing an instance of SnowflakeDataBackend.
The following fields are required:
.backendType() .config() .database() .schema() .snowflakeConnectionId() .table()
-
-
-
-