Class DataStreamParams.Body
-
- All Implemented Interfaces:
public final class DataStreamParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataStreamParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final DataStreamParams.Configconfig()Configuration for the data stream. final List<DataStreamParams.Row>rows()A list of inference data points with inputs and outputs final JsonField<DataStreamParams.Config>_config()Returns the raw JSON value of config. final JsonField<List<DataStreamParams.Row>>_rows()Returns the raw JSON value of rows. final Map<String, JsonValue>_additionalProperties()final DataStreamParams.Body.BuildertoBuilder()final DataStreamParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataStreamParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
config
final DataStreamParams.Config config()
Configuration for the data stream. Depends on your Openlayer project task type.
-
rows
final List<DataStreamParams.Row> rows()
A list of inference data points with inputs and outputs
-
_config
final JsonField<DataStreamParams.Config> _config()
Returns the raw JSON value of config.
Unlike config, this method doesn't throw if the JSON field has an unexpected type.
-
_rows
final JsonField<List<DataStreamParams.Row>> _rows()
Returns the raw JSON value of rows.
Unlike rows, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DataStreamParams.Body.Builder toBuilder()
-
validate
final DataStreamParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DataStreamParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.config() .rows()
-
-
-
-