Class DataStreamParams.Config.LlmData
-
- All Implemented Interfaces:
public final class DataStreamParams.Config.LlmData
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataStreamParams.Config.LlmData.BuilderA builder for LlmData.
public final classDataStreamParams.Config.LlmData.Prompt
-
Method Summary
Modifier and Type Method Description final StringoutputColumnName()Name of the column with the model outputs. final Optional<String>contextColumnName()Name of the column with the context retrieved. final Optional<String>costColumnName()Name of the column with the cost associated with each row. final Optional<String>groundTruthColumnName()Name of the column with the ground truths. final Optional<String>inferenceIdColumnName()Name of the column with the inference ids. final Optional<List<String>>inputVariableNames()Array of input variable names. final Optional<String>latencyColumnName()Name of the column with the latencies. final JsonValue_metadata()Object with metadata. final Optional<String>numOfTokenColumnName()Name of the column with the total number of tokens. final Optional<List<DataStreamParams.Config.LlmData.Prompt>>prompt()Prompt for the LLM. final Optional<String>questionColumnName()Name of the column with the questions. final Optional<String>sessionIdColumnName()Name of the column with the session id. final Optional<String>timestampColumnName()Name of the column with the timestamps. final Optional<String>userIdColumnName()Name of the column with the user id. final JsonField<String>_outputColumnName()Returns the raw JSON value of outputColumnName. final JsonField<String>_contextColumnName()Returns the raw JSON value of contextColumnName. final JsonField<String>_costColumnName()Returns the raw JSON value of costColumnName. final JsonField<String>_groundTruthColumnName()Returns the raw JSON value of groundTruthColumnName. final JsonField<String>_inferenceIdColumnName()Returns the raw JSON value of inferenceIdColumnName. final JsonField<List<String>>_inputVariableNames()Returns the raw JSON value of inputVariableNames. final JsonField<String>_latencyColumnName()Returns the raw JSON value of latencyColumnName. final JsonField<String>_numOfTokenColumnName()Returns the raw JSON value of numOfTokenColumnName. final JsonField<List<DataStreamParams.Config.LlmData.Prompt>>_prompt()Returns the raw JSON value of prompt. final JsonField<String>_questionColumnName()Returns the raw JSON value of questionColumnName. final JsonField<String>_sessionIdColumnName()Returns the raw JSON value of sessionIdColumnName. final JsonField<String>_timestampColumnName()Returns the raw JSON value of timestampColumnName. final JsonField<String>_userIdColumnName()Returns the raw JSON value of userIdColumnName. final Map<String, JsonValue>_additionalProperties()final DataStreamParams.Config.LlmData.BuildertoBuilder()final DataStreamParams.Config.LlmDatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataStreamParams.Config.LlmData.Builderbuilder()Returns a mutable builder for constructing an instance of LlmData. -
-
Method Detail
-
outputColumnName
final String outputColumnName()
Name of the column with the model outputs.
-
contextColumnName
final Optional<String> contextColumnName()
Name of the column with the context retrieved. Applies to RAG use cases. Providing the context enables RAG-specific metrics.
-
costColumnName
final Optional<String> costColumnName()
Name of the column with the cost associated with each row.
-
groundTruthColumnName
final Optional<String> groundTruthColumnName()
Name of the column with the ground truths.
-
inferenceIdColumnName
final Optional<String> inferenceIdColumnName()
Name of the column with the inference ids. This is useful if you want to update rows at a later point in time. If not provided, a unique id is generated by Openlayer.
-
inputVariableNames
final Optional<List<String>> inputVariableNames()
Array of input variable names. Each input variable should be a dataset column.
-
latencyColumnName
final Optional<String> latencyColumnName()
Name of the column with the latencies.
-
_metadata
final JsonValue _metadata()
Object with metadata.
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = llmData.metadata().convert(MyClass.class);
-
numOfTokenColumnName
final Optional<String> numOfTokenColumnName()
Name of the column with the total number of tokens.
-
prompt
final Optional<List<DataStreamParams.Config.LlmData.Prompt>> prompt()
Prompt for the LLM.
-
questionColumnName
final Optional<String> questionColumnName()
Name of the column with the questions. Applies to RAG use cases. Providing the question enables RAG-specific metrics.
-
sessionIdColumnName
final Optional<String> sessionIdColumnName()
Name of the column with the session id.
-
timestampColumnName
final Optional<String> timestampColumnName()
Name of the column with the timestamps. Timestamps must be in UNIX sec format. If not provided, the upload timestamp is used.
-
userIdColumnName
final Optional<String> userIdColumnName()
Name of the column with the user id.
-
_outputColumnName
final JsonField<String> _outputColumnName()
Returns the raw JSON value of outputColumnName.
Unlike outputColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_contextColumnName
final JsonField<String> _contextColumnName()
Returns the raw JSON value of contextColumnName.
Unlike contextColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_costColumnName
final JsonField<String> _costColumnName()
Returns the raw JSON value of costColumnName.
Unlike costColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_groundTruthColumnName
final JsonField<String> _groundTruthColumnName()
Returns the raw JSON value of groundTruthColumnName.
Unlike groundTruthColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_inferenceIdColumnName
final JsonField<String> _inferenceIdColumnName()
Returns the raw JSON value of inferenceIdColumnName.
Unlike inferenceIdColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_inputVariableNames
final JsonField<List<String>> _inputVariableNames()
Returns the raw JSON value of inputVariableNames.
Unlike inputVariableNames, this method doesn't throw if the JSON field has an unexpected type.
-
_latencyColumnName
final JsonField<String> _latencyColumnName()
Returns the raw JSON value of latencyColumnName.
Unlike latencyColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_numOfTokenColumnName
final JsonField<String> _numOfTokenColumnName()
Returns the raw JSON value of numOfTokenColumnName.
Unlike numOfTokenColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_prompt
final JsonField<List<DataStreamParams.Config.LlmData.Prompt>> _prompt()
Returns the raw JSON value of prompt.
Unlike prompt, this method doesn't throw if the JSON field has an unexpected type.
-
_questionColumnName
final JsonField<String> _questionColumnName()
Returns the raw JSON value of questionColumnName.
Unlike questionColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_sessionIdColumnName
final JsonField<String> _sessionIdColumnName()
Returns the raw JSON value of sessionIdColumnName.
Unlike sessionIdColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_timestampColumnName
final JsonField<String> _timestampColumnName()
Returns the raw JSON value of timestampColumnName.
Unlike timestampColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_userIdColumnName
final JsonField<String> _userIdColumnName()
Returns the raw JSON value of userIdColumnName.
Unlike userIdColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DataStreamParams.Config.LlmData.Builder toBuilder()
-
validate
final DataStreamParams.Config.LlmData validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DataStreamParams.Config.LlmData.Builder builder()
Returns a mutable builder for constructing an instance of LlmData.
The following fields are required:
.outputColumnName()
-
-
-
-