Class DataStreamParams.Config.LlmData.Prompt
-
- All Implemented Interfaces:
public final class DataStreamParams.Config.LlmData.Prompt
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataStreamParams.Config.LlmData.Prompt.BuilderA builder for Prompt.
-
Method Summary
Modifier and Type Method Description final Optional<String>content()Content of the prompt. final Optional<String>role()Role of the prompt. final JsonField<String>_content()Returns the raw JSON value of content. final JsonField<String>_role()Returns the raw JSON value of role. final Map<String, JsonValue>_additionalProperties()final DataStreamParams.Config.LlmData.Prompt.BuildertoBuilder()final DataStreamParams.Config.LlmData.Promptvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataStreamParams.Config.LlmData.Prompt.Builderbuilder()Returns a mutable builder for constructing an instance of Prompt. -
-
Method Detail
-
_content
final JsonField<String> _content()
Returns the raw JSON value of content.
Unlike content, this method doesn't throw if the JSON field has an unexpected type.
-
_role
final JsonField<String> _role()
Returns the raw JSON value of role.
Unlike role, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DataStreamParams.Config.LlmData.Prompt.Builder toBuilder()
-
validate
final DataStreamParams.Config.LlmData.Prompt validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DataStreamParams.Config.LlmData.Prompt.Builder builder()
Returns a mutable builder for constructing an instance of Prompt.
-
-
-
-