Class DataStreamParams.Config.TabularRegressionData
-
- All Implemented Interfaces:
public final class DataStreamParams.Config.TabularRegressionData
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataStreamParams.Config.TabularRegressionData.BuilderA builder for TabularRegressionData.
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>categoricalFeatureNames()Array with the names of all categorical features in the dataset. final Optional<List<String>>featureNames()Array with all input feature names. final Optional<String>inferenceIdColumnName()Name of the column with the inference ids. final Optional<String>latencyColumnName()Name of the column with the latencies. final JsonValue_metadata()Object with metadata. final Optional<String>predictionsColumnName()Name of the column with the model's predictions. final Optional<String>targetColumnName()Name of the column with the targets (ground truth values). final Optional<String>timestampColumnName()Name of the column with the timestamps. final JsonField<List<String>>_categoricalFeatureNames()Returns the raw JSON value of categoricalFeatureNames. final JsonField<List<String>>_featureNames()Returns the raw JSON value of featureNames. final JsonField<String>_inferenceIdColumnName()Returns the raw JSON value of inferenceIdColumnName. final JsonField<String>_latencyColumnName()Returns the raw JSON value of latencyColumnName. final JsonField<String>_predictionsColumnName()Returns the raw JSON value of predictionsColumnName. final JsonField<String>_targetColumnName()Returns the raw JSON value of targetColumnName. final JsonField<String>_timestampColumnName()Returns the raw JSON value of timestampColumnName. final Map<String, JsonValue>_additionalProperties()final DataStreamParams.Config.TabularRegressionData.BuildertoBuilder()final DataStreamParams.Config.TabularRegressionDatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataStreamParams.Config.TabularRegressionData.Builderbuilder()Returns a mutable builder for constructing an instance of TabularRegressionData. -
-
Method Detail
-
categoricalFeatureNames
final Optional<List<String>> categoricalFeatureNames()
Array with the names of all categorical features in the dataset. E.g. "Gender", "Geography".
-
featureNames
final Optional<List<String>> featureNames()
Array with all input feature names.
-
inferenceIdColumnName
final Optional<String> inferenceIdColumnName()
Name of the column with the inference ids. This is useful if you want to update rows at a later point in time. If not provided, a unique id is generated by Openlayer.
-
latencyColumnName
final Optional<String> latencyColumnName()
Name of the column with the latencies.
-
_metadata
final JsonValue _metadata()
Object with metadata.
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = tabularRegressionData.metadata().convert(MyClass.class);
-
predictionsColumnName
final Optional<String> predictionsColumnName()
Name of the column with the model's predictions.
-
targetColumnName
final Optional<String> targetColumnName()
Name of the column with the targets (ground truth values).
-
timestampColumnName
final Optional<String> timestampColumnName()
Name of the column with the timestamps. Timestamps must be in UNIX sec format. If not provided, the upload timestamp is used.
-
_categoricalFeatureNames
final JsonField<List<String>> _categoricalFeatureNames()
Returns the raw JSON value of categoricalFeatureNames.
Unlike categoricalFeatureNames, this method doesn't throw if the JSON field has an unexpected type.
-
_featureNames
final JsonField<List<String>> _featureNames()
Returns the raw JSON value of featureNames.
Unlike featureNames, this method doesn't throw if the JSON field has an unexpected type.
-
_inferenceIdColumnName
final JsonField<String> _inferenceIdColumnName()
Returns the raw JSON value of inferenceIdColumnName.
Unlike inferenceIdColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_latencyColumnName
final JsonField<String> _latencyColumnName()
Returns the raw JSON value of latencyColumnName.
Unlike latencyColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_predictionsColumnName
final JsonField<String> _predictionsColumnName()
Returns the raw JSON value of predictionsColumnName.
Unlike predictionsColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_targetColumnName
final JsonField<String> _targetColumnName()
Returns the raw JSON value of targetColumnName.
Unlike targetColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_timestampColumnName
final JsonField<String> _timestampColumnName()
Returns the raw JSON value of timestampColumnName.
Unlike timestampColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DataStreamParams.Config.TabularRegressionData.Builder toBuilder()
-
validate
final DataStreamParams.Config.TabularRegressionData validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DataStreamParams.Config.TabularRegressionData.Builder builder()
Returns a mutable builder for constructing an instance of TabularRegressionData.
-
-
-
-