Class DataStreamParams.Config.TextClassificationData
-
- All Implemented Interfaces:
public final class DataStreamParams.Config.TextClassificationData
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classDataStreamParams.Config.TextClassificationData.BuilderA builder for TextClassificationData.
-
Method Summary
Modifier and Type Method Description final List<String>classNames()List of class names indexed by label integer in the dataset. final Optional<String>inferenceIdColumnName()Name of the column with the inference ids. final Optional<String>labelColumnName()Name of the column with the labels. final Optional<String>latencyColumnName()Name of the column with the latencies. final JsonValue_metadata()Object with metadata. final Optional<String>predictionsColumnName()Name of the column with the model's predictions as zero-indexed integers. final Optional<String>predictionScoresColumnName()Name of the column with the model's predictions as lists of class probabilities. final Optional<String>textColumnName()Name of the column with the text data. final Optional<String>timestampColumnName()Name of the column with the timestamps. final JsonField<List<String>>_classNames()Returns the raw JSON value of classNames. final JsonField<String>_inferenceIdColumnName()Returns the raw JSON value of inferenceIdColumnName. final JsonField<String>_labelColumnName()Returns the raw JSON value of labelColumnName. final JsonField<String>_latencyColumnName()Returns the raw JSON value of latencyColumnName. final JsonField<String>_predictionsColumnName()Returns the raw JSON value of predictionsColumnName. final JsonField<String>_predictionScoresColumnName()Returns the raw JSON value of predictionScoresColumnName. final JsonField<String>_textColumnName()Returns the raw JSON value of textColumnName. final JsonField<String>_timestampColumnName()Returns the raw JSON value of timestampColumnName. final Map<String, JsonValue>_additionalProperties()final DataStreamParams.Config.TextClassificationData.BuildertoBuilder()final DataStreamParams.Config.TextClassificationDatavalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static DataStreamParams.Config.TextClassificationData.Builderbuilder()Returns a mutable builder for constructing an instance of TextClassificationData. -
-
Method Detail
-
classNames
final List<String> classNames()
List of class names indexed by label integer in the dataset. E.g. "Retained", "Exited" when 0, 1 are in your label column.
-
inferenceIdColumnName
final Optional<String> inferenceIdColumnName()
Name of the column with the inference ids. This is useful if you want to update rows at a later point in time. If not provided, a unique id is generated by Openlayer.
-
labelColumnName
final Optional<String> labelColumnName()
Name of the column with the labels. The data in this column must be zero-indexed integers, matching the list provided in
classNames.
-
latencyColumnName
final Optional<String> latencyColumnName()
Name of the column with the latencies.
-
_metadata
final JsonValue _metadata()
Object with metadata.
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = textClassificationData.metadata().convert(MyClass.class);
-
predictionsColumnName
final Optional<String> predictionsColumnName()
Name of the column with the model's predictions as zero-indexed integers.
-
predictionScoresColumnName
final Optional<String> predictionScoresColumnName()
Name of the column with the model's predictions as lists of class probabilities.
-
textColumnName
final Optional<String> textColumnName()
Name of the column with the text data.
-
timestampColumnName
final Optional<String> timestampColumnName()
Name of the column with the timestamps. Timestamps must be in UNIX sec format. If not provided, the upload timestamp is used.
-
_classNames
final JsonField<List<String>> _classNames()
Returns the raw JSON value of classNames.
Unlike classNames, this method doesn't throw if the JSON field has an unexpected type.
-
_inferenceIdColumnName
final JsonField<String> _inferenceIdColumnName()
Returns the raw JSON value of inferenceIdColumnName.
Unlike inferenceIdColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_labelColumnName
final JsonField<String> _labelColumnName()
Returns the raw JSON value of labelColumnName.
Unlike labelColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_latencyColumnName
final JsonField<String> _latencyColumnName()
Returns the raw JSON value of latencyColumnName.
Unlike latencyColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_predictionsColumnName
final JsonField<String> _predictionsColumnName()
Returns the raw JSON value of predictionsColumnName.
Unlike predictionsColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_predictionScoresColumnName
final JsonField<String> _predictionScoresColumnName()
Returns the raw JSON value of predictionScoresColumnName.
Unlike predictionScoresColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_textColumnName
final JsonField<String> _textColumnName()
Returns the raw JSON value of textColumnName.
Unlike textColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_timestampColumnName
final JsonField<String> _timestampColumnName()
Returns the raw JSON value of timestampColumnName.
Unlike timestampColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final DataStreamParams.Config.TextClassificationData.Builder toBuilder()
-
validate
final DataStreamParams.Config.TextClassificationData validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static DataStreamParams.Config.TextClassificationData.Builder builder()
Returns a mutable builder for constructing an instance of TextClassificationData.
The following fields are required:
.classNames()
-
-
-
-