Class RowListParams
-
- All Implemented Interfaces:
-
com.openlayer.api.core.Params
public final class RowListParams implements Params
A list of rows for an inference pipeline.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRowListParams.BuilderA builder for RowListParams.
public final classRowListParams.Bodypublic final classRowListParams.ColumnFilter
-
Method Summary
Modifier and Type Method Description final Optional<String>inferencePipelineId()final Optional<Boolean>asc()Whether or not to sort on the sortColumn in ascending order. final Optional<Long>page()The page to return in a paginated query. final Optional<Long>perPage()Maximum number of items to return per page. final Optional<String>sortColumn()Name of the column to sort on final Optional<List<RowListParams.ColumnFilter>>columnFilters()final Optional<List<Long>>excludeRowIdList()final Optional<List<String>>notSearchQueryAnd()final Optional<List<String>>notSearchQueryOr()final Optional<List<Long>>rowIdList()final Optional<List<String>>searchQueryAnd()final Optional<List<String>>searchQueryOr()final JsonField<List<RowListParams.ColumnFilter>>_columnFilters()Returns the raw JSON value of columnFilters. final JsonField<List<Long>>_excludeRowIdList()Returns the raw JSON value of excludeRowIdList. final JsonField<List<String>>_notSearchQueryAnd()Returns the raw JSON value of notSearchQueryAnd. final JsonField<List<String>>_notSearchQueryOr()Returns the raw JSON value of notSearchQueryOr. final JsonField<List<Long>>_rowIdList()Returns the raw JSON value of rowIdList. final JsonField<List<String>>_searchQueryAnd()Returns the raw JSON value of searchQueryAnd. final JsonField<List<String>>_searchQueryOr()Returns the raw JSON value of searchQueryOr. final Map<String, JsonValue>_additionalBodyProperties()final Headers_additionalHeaders()Additional headers to send with the request. final QueryParams_additionalQueryParams()Additional query param to send with the request. final RowListParams.BuildertoBuilder()final RowListParams.Body_body()final String_pathParam(Integer index)Headers_headers()The full set of headers in the parameters, including both fixed and additional headers. QueryParams_queryParams()The full set of query params in the parameters, including both fixed and additional query params. Booleanequals(Object other)IntegerhashCode()StringtoString()final static RowListParamsnone()final static RowListParams.Builderbuilder()Returns a mutable builder for constructing an instance of RowListParams. -
-
Method Detail
-
inferencePipelineId
final Optional<String> inferencePipelineId()
-
sortColumn
final Optional<String> sortColumn()
Name of the column to sort on
-
columnFilters
final Optional<List<RowListParams.ColumnFilter>> columnFilters()
-
excludeRowIdList
final Optional<List<Long>> excludeRowIdList()
-
notSearchQueryAnd
final Optional<List<String>> notSearchQueryAnd()
-
notSearchQueryOr
final Optional<List<String>> notSearchQueryOr()
-
searchQueryAnd
final Optional<List<String>> searchQueryAnd()
-
searchQueryOr
final Optional<List<String>> searchQueryOr()
-
_columnFilters
final JsonField<List<RowListParams.ColumnFilter>> _columnFilters()
Returns the raw JSON value of columnFilters.
Unlike columnFilters, this method doesn't throw if the JSON field has an unexpected type.
-
_excludeRowIdList
final JsonField<List<Long>> _excludeRowIdList()
Returns the raw JSON value of excludeRowIdList.
Unlike excludeRowIdList, this method doesn't throw if the JSON field has an unexpected type.
-
_notSearchQueryAnd
final JsonField<List<String>> _notSearchQueryAnd()
Returns the raw JSON value of notSearchQueryAnd.
Unlike notSearchQueryAnd, this method doesn't throw if the JSON field has an unexpected type.
-
_notSearchQueryOr
final JsonField<List<String>> _notSearchQueryOr()
Returns the raw JSON value of notSearchQueryOr.
Unlike notSearchQueryOr, this method doesn't throw if the JSON field has an unexpected type.
-
_rowIdList
final JsonField<List<Long>> _rowIdList()
Returns the raw JSON value of rowIdList.
Unlike rowIdList, this method doesn't throw if the JSON field has an unexpected type.
-
_searchQueryAnd
final JsonField<List<String>> _searchQueryAnd()
Returns the raw JSON value of searchQueryAnd.
Unlike searchQueryAnd, this method doesn't throw if the JSON field has an unexpected type.
-
_searchQueryOr
final JsonField<List<String>> _searchQueryOr()
Returns the raw JSON value of searchQueryOr.
Unlike searchQueryOr, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final RowListParams.Builder toBuilder()
-
_body
final RowListParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static RowListParams none()
-
builder
final static RowListParams.Builder builder()
Returns a mutable builder for constructing an instance of RowListParams.
-
-
-
-