Class RowListResponse
-
- All Implemented Interfaces:
public final class RowListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRowListResponse.BuilderA builder for RowListResponse.
public final classRowListResponse.Item
-
Method Summary
Modifier and Type Method Description final List<RowListResponse.Item>items()final JsonField<List<RowListResponse.Item>>_items()Returns the raw JSON value of items. final Map<String, JsonValue>_additionalProperties()final RowListResponse.BuildertoBuilder()final RowListResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RowListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of RowListResponse. -
-
Method Detail
-
items
final List<RowListResponse.Item> items()
-
_items
final JsonField<List<RowListResponse.Item>> _items()
Returns the raw JSON value of items.
Unlike items, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RowListResponse.Builder toBuilder()
-
validate
final RowListResponse validate()
-
builder
final static RowListResponse.Builder builder()
Returns a mutable builder for constructing an instance of RowListResponse.
The following fields are required:
.items()
-
-
-
-