Class RowListResponse.Item.Builder
-
- All Implemented Interfaces:
public final class RowListResponse.Item.BuilderA builder for Item.
-
-
Method Summary
Modifier and Type Method Description final RowListResponse.Item.BuilderopenlayerRowId(Long openlayerRowId)final RowListResponse.Item.BuilderopenlayerRowId(JsonField<Long> openlayerRowId)Sets Builder.openlayerRowId to an arbitrary JSON value. final RowListResponse.Item.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final RowListResponse.Item.BuilderputAdditionalProperty(String key, JsonValue value)final RowListResponse.Item.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final RowListResponse.Item.BuilderremoveAdditionalProperty(String key)final RowListResponse.Item.BuilderremoveAllAdditionalProperties(Set<String> keys)final RowListResponse.Itembuild()Returns an immutable instance of Item. -
-
Method Detail
-
openlayerRowId
final RowListResponse.Item.Builder openlayerRowId(Long openlayerRowId)
-
openlayerRowId
final RowListResponse.Item.Builder openlayerRowId(JsonField<Long> openlayerRowId)
Sets Builder.openlayerRowId to an arbitrary JSON value.
You should usually call Builder.openlayerRowId with a well-typed Long value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RowListResponse.Item.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RowListResponse.Item.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RowListResponse.Item.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RowListResponse.Item.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RowListResponse.Item.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RowListResponse.Item build()
Returns an immutable instance of Item.
Further updates to this Builder will not mutate the returned instance.
The following fields are required:
.openlayerRowId()
-
-
-
-