Class RowRetrieveResponse.Builder
-
- All Implemented Interfaces:
public final class RowRetrieveResponse.BuilderA builder for RowRetrieveResponse.
-
-
Method Summary
Modifier and Type Method Description final RowRetrieveResponse.Builderrow(JsonValue row)final RowRetrieveResponse.Buildersuccess(Boolean success)final RowRetrieveResponse.Buildersuccess(JsonField<Boolean> success)Sets Builder.success to an arbitrary JSON value. final RowRetrieveResponse.BuilderadditionalProperties(Map<String, JsonValue> additionalProperties)final RowRetrieveResponse.BuilderputAdditionalProperty(String key, JsonValue value)final RowRetrieveResponse.BuilderputAllAdditionalProperties(Map<String, JsonValue> additionalProperties)final RowRetrieveResponse.BuilderremoveAdditionalProperty(String key)final RowRetrieveResponse.BuilderremoveAllAdditionalProperties(Set<String> keys)final RowRetrieveResponsebuild()Returns an immutable instance of RowRetrieveResponse. -
-
Method Detail
-
row
final RowRetrieveResponse.Builder row(JsonValue row)
-
success
final RowRetrieveResponse.Builder success(Boolean success)
-
success
final RowRetrieveResponse.Builder success(JsonField<Boolean> success)
Sets Builder.success to an arbitrary JSON value.
You should usually call Builder.success with a well-typed Boolean value instead. This method is primarily for setting the field to an undocumented or not yet supported value.
-
additionalProperties
final RowRetrieveResponse.Builder additionalProperties(Map<String, JsonValue> additionalProperties)
-
putAdditionalProperty
final RowRetrieveResponse.Builder putAdditionalProperty(String key, JsonValue value)
-
putAllAdditionalProperties
final RowRetrieveResponse.Builder putAllAdditionalProperties(Map<String, JsonValue> additionalProperties)
-
removeAdditionalProperty
final RowRetrieveResponse.Builder removeAdditionalProperty(String key)
-
removeAllAdditionalProperties
final RowRetrieveResponse.Builder removeAllAdditionalProperties(Set<String> keys)
-
build
final RowRetrieveResponse build()
Returns an immutable instance of RowRetrieveResponse.
Further updates to this Builder will not mutate the returned instance.
-
-
-
-