Class RowUpdateParams.Body
-
- All Implemented Interfaces:
public final class RowUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRowUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final JsonValue_row()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = body.row().convert(MyClass.class);final Optional<RowUpdateParams.Config>config()final JsonField<RowUpdateParams.Config>_config()Returns the raw JSON value of config. final Map<String, JsonValue>_additionalProperties()final RowUpdateParams.Body.BuildertoBuilder()final RowUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RowUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
_row
final JsonValue _row()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = body.row().convert(MyClass.class);
-
config
final Optional<RowUpdateParams.Config> config()
-
_config
final JsonField<RowUpdateParams.Config> _config()
Returns the raw JSON value of config.
Unlike config, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RowUpdateParams.Body.Builder toBuilder()
-
validate
final RowUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RowUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.row()
-
-
-
-