Class RowUpdateParams.Config
-
- All Implemented Interfaces:
public final class RowUpdateParams.Config
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRowUpdateParams.Config.BuilderA builder for Config.
-
Method Summary
Modifier and Type Method Description final Optional<String>groundTruthColumnName()Name of the column with the ground truths. final Optional<String>humanFeedbackColumnName()Name of the column with human feedback. final Optional<String>inferenceIdColumnName()Name of the column with the inference ids. final Optional<String>latencyColumnName()Name of the column with the latencies. final Optional<String>timestampColumnName()Name of the column with the timestamps. final JsonField<String>_groundTruthColumnName()Returns the raw JSON value of groundTruthColumnName. final JsonField<String>_humanFeedbackColumnName()Returns the raw JSON value of humanFeedbackColumnName. final JsonField<String>_inferenceIdColumnName()Returns the raw JSON value of inferenceIdColumnName. final JsonField<String>_latencyColumnName()Returns the raw JSON value of latencyColumnName. final JsonField<String>_timestampColumnName()Returns the raw JSON value of timestampColumnName. final Map<String, JsonValue>_additionalProperties()final RowUpdateParams.Config.BuildertoBuilder()final RowUpdateParams.Configvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RowUpdateParams.Config.Builderbuilder()Returns a mutable builder for constructing an instance of Config. -
-
Method Detail
-
groundTruthColumnName
final Optional<String> groundTruthColumnName()
Name of the column with the ground truths.
-
humanFeedbackColumnName
final Optional<String> humanFeedbackColumnName()
Name of the column with human feedback.
-
inferenceIdColumnName
final Optional<String> inferenceIdColumnName()
Name of the column with the inference ids. This is useful if you want to update rows at a later point in time. If not provided, a unique id is generated by Openlayer.
-
latencyColumnName
final Optional<String> latencyColumnName()
Name of the column with the latencies.
-
timestampColumnName
final Optional<String> timestampColumnName()
Name of the column with the timestamps. Timestamps must be in UNIX sec format. If not provided, the upload timestamp is used.
-
_groundTruthColumnName
final JsonField<String> _groundTruthColumnName()
Returns the raw JSON value of groundTruthColumnName.
Unlike groundTruthColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_humanFeedbackColumnName
final JsonField<String> _humanFeedbackColumnName()
Returns the raw JSON value of humanFeedbackColumnName.
Unlike humanFeedbackColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_inferenceIdColumnName
final JsonField<String> _inferenceIdColumnName()
Returns the raw JSON value of inferenceIdColumnName.
Unlike inferenceIdColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_latencyColumnName
final JsonField<String> _latencyColumnName()
Returns the raw JSON value of latencyColumnName.
Unlike latencyColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_timestampColumnName
final JsonField<String> _timestampColumnName()
Returns the raw JSON value of timestampColumnName.
Unlike timestampColumnName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RowUpdateParams.Config.Builder toBuilder()
-
validate
final RowUpdateParams.Config validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RowUpdateParams.Config.Builder builder()
Returns a mutable builder for constructing an instance of Config.
-
-
-
-