Class RowUpdateResponse
-
- All Implemented Interfaces:
public final class RowUpdateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRowUpdateResponse.BuilderA builder for RowUpdateResponse.
public final classRowUpdateResponse.Success
-
Method Summary
Modifier and Type Method Description final RowUpdateResponse.Successsuccess()final JsonField<RowUpdateResponse.Success>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final RowUpdateResponse.BuildertoBuilder()final RowUpdateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RowUpdateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of RowUpdateResponse. -
-
Method Detail
-
success
final RowUpdateResponse.Success success()
-
_success
final JsonField<RowUpdateResponse.Success> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RowUpdateResponse.Builder toBuilder()
-
validate
final RowUpdateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static RowUpdateResponse.Builder builder()
Returns a mutable builder for constructing an instance of RowUpdateResponse.
The following fields are required:
.success()
-
-
-
-