Class ProjectCreateParams.Links
-
- All Implemented Interfaces:
public final class ProjectCreateParams.LinksLinks to the project.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateParams.Links.BuilderA builder for Links.
-
Method Summary
Modifier and Type Method Description final Stringapp()final JsonField<String>_app()Returns the raw JSON value of app. final Map<String, JsonValue>_additionalProperties()final ProjectCreateParams.Links.BuildertoBuilder()final ProjectCreateParams.Linksvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateParams.Links.Builderbuilder()Returns a mutable builder for constructing an instance of Links. -
-
Method Detail
-
_app
final JsonField<String> _app()
Returns the raw JSON value of app.
Unlike app, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectCreateParams.Links.Builder toBuilder()
-
validate
final ProjectCreateParams.Links validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProjectCreateParams.Links.Builder builder()
Returns a mutable builder for constructing an instance of Links.
The following fields are required:
.app()
-
-
-
-