Class ProjectCreateResponse.Links
-
- All Implemented Interfaces:
public final class ProjectCreateResponse.LinksLinks to the project.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectCreateResponse.Links.BuilderA builder for Links.
-
Method Summary
Modifier and Type Method Description final Stringapp()final JsonField<String>_app()Returns the raw JSON value of app. final Map<String, JsonValue>_additionalProperties()final ProjectCreateResponse.Links.BuildertoBuilder()final ProjectCreateResponse.Linksvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectCreateResponse.Links.Builderbuilder()Returns a mutable builder for constructing an instance of Links. -
-
Method Detail
-
_app
final JsonField<String> _app()
Returns the raw JSON value of app.
Unlike app, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectCreateResponse.Links.Builder toBuilder()
-
validate
final ProjectCreateResponse.Links validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProjectCreateResponse.Links.Builder builder()
Returns a mutable builder for constructing an instance of Links.
The following fields are required:
.app()
-
-
-
-