Class ProjectListResponse.Item.GitRepo
-
- All Implemented Interfaces:
public final class ProjectListResponse.Item.GitRepo
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classProjectListResponse.Item.GitRepo.BuilderA builder for GitRepo.
-
Method Summary
Modifier and Type Method Description final Stringid()final OffsetDateTimedateConnected()final OffsetDateTimedateUpdated()final StringgitAccountId()final LonggitId()final Stringname()final Booleanprivate_()final StringprojectId()final Stringslug()final Stringurl()final Optional<String>branch()final Optional<String>rootDir()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_dateConnected()Returns the raw JSON value of dateConnected. final JsonField<OffsetDateTime>_dateUpdated()Returns the raw JSON value of dateUpdated. final JsonField<String>_gitAccountId()Returns the raw JSON value of gitAccountId. final JsonField<Long>_gitId()Returns the raw JSON value of gitId. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<Boolean>_private_()Returns the raw JSON value of private_. final JsonField<String>_projectId()Returns the raw JSON value of projectId. final JsonField<String>_slug()Returns the raw JSON value of slug. final JsonField<String>_url()Returns the raw JSON value of url. final JsonField<String>_branch()Returns the raw JSON value of branch. final JsonField<String>_rootDir()Returns the raw JSON value of rootDir. final Map<String, JsonValue>_additionalProperties()final ProjectListResponse.Item.GitRepo.BuildertoBuilder()final ProjectListResponse.Item.GitRepovalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ProjectListResponse.Item.GitRepo.Builderbuilder()Returns a mutable builder for constructing an instance of GitRepo. -
-
Method Detail
-
dateConnected
final OffsetDateTime dateConnected()
-
dateUpdated
final OffsetDateTime dateUpdated()
-
gitAccountId
final String gitAccountId()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_dateConnected
final JsonField<OffsetDateTime> _dateConnected()
Returns the raw JSON value of dateConnected.
Unlike dateConnected, this method doesn't throw if the JSON field has an unexpected type.
-
_dateUpdated
final JsonField<OffsetDateTime> _dateUpdated()
Returns the raw JSON value of dateUpdated.
Unlike dateUpdated, this method doesn't throw if the JSON field has an unexpected type.
-
_gitAccountId
final JsonField<String> _gitAccountId()
Returns the raw JSON value of gitAccountId.
Unlike gitAccountId, this method doesn't throw if the JSON field has an unexpected type.
-
_gitId
final JsonField<Long> _gitId()
Returns the raw JSON value of gitId.
Unlike gitId, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_private_
final JsonField<Boolean> _private_()
Returns the raw JSON value of private_.
Unlike private_, this method doesn't throw if the JSON field has an unexpected type.
-
_projectId
final JsonField<String> _projectId()
Returns the raw JSON value of projectId.
Unlike projectId, this method doesn't throw if the JSON field has an unexpected type.
-
_slug
final JsonField<String> _slug()
Returns the raw JSON value of slug.
Unlike slug, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_branch
final JsonField<String> _branch()
Returns the raw JSON value of branch.
Unlike branch, this method doesn't throw if the JSON field has an unexpected type.
-
_rootDir
final JsonField<String> _rootDir()
Returns the raw JSON value of rootDir.
Unlike rootDir, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ProjectListResponse.Item.GitRepo.Builder toBuilder()
-
validate
final ProjectListResponse.Item.GitRepo validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ProjectListResponse.Item.GitRepo.Builder builder()
Returns a mutable builder for constructing an instance of GitRepo.
The following fields are required:
.id() .dateConnected() .dateUpdated() .gitAccountId() .gitId() .name() .private_() .projectId() .slug() .url()
-
-
-
-