Class CommitCreateParams.Body
-
- All Implemented Interfaces:
public final class CommitCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCommitCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Stringid()The project version (commit) id. final CommitCreateParams.Commitcommit()The details of a commit (project version). final Optional<OffsetDateTime>dateArchived()The commit archive date. final OffsetDateTimedateCreated()The project version (commit) creation date. final LongfailingGoalCount()The number of tests that are failing for the commit. final Optional<String>mlModelId()The model id. final LongpassingGoalCount()The number of tests that are passing for the commit. final StringbodyProjectId()The project id. final CommitCreateParams.Statusstatus()The commit status. final Optional<String>statusMessage()The commit status message. final StringstorageUri()The storage URI where the commit bundle is stored. final LongtotalGoalCount()The total number of tests for the commit. final Optional<String>trainingDatasetId()The training dataset id. final Optional<String>validationDatasetId()The validation dataset id. final Optional<Boolean>archived()Whether the commit is archived. final Optional<String>deploymentStatus()The deployment status associated with the commit's model. final Optional<CommitCreateParams.Links>links()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<CommitCreateParams.Commit>_commit()Returns the raw JSON value of commit. final JsonField<OffsetDateTime>_dateArchived()Returns the raw JSON value of dateArchived. final JsonField<OffsetDateTime>_dateCreated()Returns the raw JSON value of dateCreated. final JsonField<Long>_failingGoalCount()Returns the raw JSON value of failingGoalCount. final JsonField<String>_mlModelId()Returns the raw JSON value of mlModelId. final JsonField<Long>_passingGoalCount()Returns the raw JSON value of passingGoalCount. final JsonField<String>_bodyProjectId()Returns the raw JSON value of bodyProjectId. final JsonField<CommitCreateParams.Status>_status()Returns the raw JSON value of status. final JsonField<String>_statusMessage()Returns the raw JSON value of statusMessage. final JsonField<String>_storageUri()Returns the raw JSON value of storageUri. final JsonField<Long>_totalGoalCount()Returns the raw JSON value of totalGoalCount. final JsonField<String>_trainingDatasetId()Returns the raw JSON value of trainingDatasetId. final JsonField<String>_validationDatasetId()Returns the raw JSON value of validationDatasetId. final JsonField<Boolean>_archived()Returns the raw JSON value of archived. final JsonField<String>_deploymentStatus()Returns the raw JSON value of deploymentStatus. final JsonField<CommitCreateParams.Links>_links()Returns the raw JSON value of links. final Map<String, JsonValue>_additionalProperties()final CommitCreateParams.Body.BuildertoBuilder()final CommitCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CommitCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
commit
final CommitCreateParams.Commit commit()
The details of a commit (project version).
-
dateArchived
final Optional<OffsetDateTime> dateArchived()
The commit archive date.
-
dateCreated
final OffsetDateTime dateCreated()
The project version (commit) creation date.
-
failingGoalCount
final Long failingGoalCount()
The number of tests that are failing for the commit.
-
passingGoalCount
final Long passingGoalCount()
The number of tests that are passing for the commit.
-
bodyProjectId
final String bodyProjectId()
The project id.
-
status
final CommitCreateParams.Status status()
The commit status. Initially, the commit is
queued, then, it switches torunning. Finally, it can bepaused,failed, orcompleted.
-
statusMessage
final Optional<String> statusMessage()
The commit status message.
-
storageUri
final String storageUri()
The storage URI where the commit bundle is stored.
-
totalGoalCount
final Long totalGoalCount()
The total number of tests for the commit.
-
trainingDatasetId
final Optional<String> trainingDatasetId()
The training dataset id.
-
validationDatasetId
final Optional<String> validationDatasetId()
The validation dataset id.
-
deploymentStatus
final Optional<String> deploymentStatus()
The deployment status associated with the commit's model.
-
links
final Optional<CommitCreateParams.Links> links()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_commit
final JsonField<CommitCreateParams.Commit> _commit()
Returns the raw JSON value of commit.
Unlike commit, this method doesn't throw if the JSON field has an unexpected type.
-
_dateArchived
final JsonField<OffsetDateTime> _dateArchived()
Returns the raw JSON value of dateArchived.
Unlike dateArchived, this method doesn't throw if the JSON field has an unexpected type.
-
_dateCreated
final JsonField<OffsetDateTime> _dateCreated()
Returns the raw JSON value of dateCreated.
Unlike dateCreated, this method doesn't throw if the JSON field has an unexpected type.
-
_failingGoalCount
final JsonField<Long> _failingGoalCount()
Returns the raw JSON value of failingGoalCount.
Unlike failingGoalCount, this method doesn't throw if the JSON field has an unexpected type.
-
_mlModelId
final JsonField<String> _mlModelId()
Returns the raw JSON value of mlModelId.
Unlike mlModelId, this method doesn't throw if the JSON field has an unexpected type.
-
_passingGoalCount
final JsonField<Long> _passingGoalCount()
Returns the raw JSON value of passingGoalCount.
Unlike passingGoalCount, this method doesn't throw if the JSON field has an unexpected type.
-
_bodyProjectId
final JsonField<String> _bodyProjectId()
Returns the raw JSON value of bodyProjectId.
Unlike bodyProjectId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CommitCreateParams.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_statusMessage
final JsonField<String> _statusMessage()
Returns the raw JSON value of statusMessage.
Unlike statusMessage, this method doesn't throw if the JSON field has an unexpected type.
-
_storageUri
final JsonField<String> _storageUri()
Returns the raw JSON value of storageUri.
Unlike storageUri, this method doesn't throw if the JSON field has an unexpected type.
-
_totalGoalCount
final JsonField<Long> _totalGoalCount()
Returns the raw JSON value of totalGoalCount.
Unlike totalGoalCount, this method doesn't throw if the JSON field has an unexpected type.
-
_trainingDatasetId
final JsonField<String> _trainingDatasetId()
Returns the raw JSON value of trainingDatasetId.
Unlike trainingDatasetId, this method doesn't throw if the JSON field has an unexpected type.
-
_validationDatasetId
final JsonField<String> _validationDatasetId()
Returns the raw JSON value of validationDatasetId.
Unlike validationDatasetId, this method doesn't throw if the JSON field has an unexpected type.
-
_archived
final JsonField<Boolean> _archived()
Returns the raw JSON value of archived.
Unlike archived, this method doesn't throw if the JSON field has an unexpected type.
-
_deploymentStatus
final JsonField<String> _deploymentStatus()
Returns the raw JSON value of deploymentStatus.
Unlike deploymentStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_links
final JsonField<CommitCreateParams.Links> _links()
Returns the raw JSON value of links.
Unlike links, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CommitCreateParams.Body.Builder toBuilder()
-
validate
final CommitCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CommitCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.id() .commit() .dateArchived() .dateCreated() .failingGoalCount() .mlModelId() .passingGoalCount() .bodyProjectId() .status() .statusMessage() .storageUri() .totalGoalCount() .trainingDatasetId() .validationDatasetId()
-
-
-
-