Class CommitListResponse.Item
-
- All Implemented Interfaces:
public final class CommitListResponse.Item
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCommitListResponse.Item.BuilderA builder for Item.
public final classCommitListResponse.Item.CommitThe details of a commit (project version).
public final classCommitListResponse.Item.StatusThe commit status. Initially, the commit is
queued, then, it switches torunning. Finally, it can bepaused,failed, orcompleted.public final classCommitListResponse.Item.Links
-
Method Summary
Modifier and Type Method Description final Stringid()The project version (commit) id. final CommitListResponse.Item.Commitcommit()The details of a commit (project version). final Optional<OffsetDateTime>dateArchived()The commit archive date. final OffsetDateTimedateCreated()The project version (commit) creation date. final LongfailingGoalCount()The number of tests that are failing for the commit. final Optional<String>mlModelId()The model id. final LongpassingGoalCount()The number of tests that are passing for the commit. final StringprojectId()The project id. final CommitListResponse.Item.Statusstatus()The commit status. final Optional<String>statusMessage()The commit status message. final StringstorageUri()The storage URI where the commit bundle is stored. final LongtotalGoalCount()The total number of tests for the commit. final Optional<String>trainingDatasetId()The training dataset id. final Optional<String>validationDatasetId()The validation dataset id. final Optional<Boolean>archived()Whether the commit is archived. final Optional<String>deploymentStatus()The deployment status associated with the commit's model. final Optional<CommitListResponse.Item.Links>links()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<CommitListResponse.Item.Commit>_commit()Returns the raw JSON value of commit. final JsonField<OffsetDateTime>_dateArchived()Returns the raw JSON value of dateArchived. final JsonField<OffsetDateTime>_dateCreated()Returns the raw JSON value of dateCreated. final JsonField<Long>_failingGoalCount()Returns the raw JSON value of failingGoalCount. final JsonField<String>_mlModelId()Returns the raw JSON value of mlModelId. final JsonField<Long>_passingGoalCount()Returns the raw JSON value of passingGoalCount. final JsonField<String>_projectId()Returns the raw JSON value of projectId. final JsonField<CommitListResponse.Item.Status>_status()Returns the raw JSON value of status. final JsonField<String>_statusMessage()Returns the raw JSON value of statusMessage. final JsonField<String>_storageUri()Returns the raw JSON value of storageUri. final JsonField<Long>_totalGoalCount()Returns the raw JSON value of totalGoalCount. final JsonField<String>_trainingDatasetId()Returns the raw JSON value of trainingDatasetId. final JsonField<String>_validationDatasetId()Returns the raw JSON value of validationDatasetId. final JsonField<Boolean>_archived()Returns the raw JSON value of archived. final JsonField<String>_deploymentStatus()Returns the raw JSON value of deploymentStatus. final JsonField<CommitListResponse.Item.Links>_links()Returns the raw JSON value of links. final Map<String, JsonValue>_additionalProperties()final CommitListResponse.Item.BuildertoBuilder()final CommitListResponse.Itemvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CommitListResponse.Item.Builderbuilder()Returns a mutable builder for constructing an instance of Item. -
-
Method Detail
-
commit
final CommitListResponse.Item.Commit commit()
The details of a commit (project version).
-
dateArchived
final Optional<OffsetDateTime> dateArchived()
The commit archive date.
-
dateCreated
final OffsetDateTime dateCreated()
The project version (commit) creation date.
-
failingGoalCount
final Long failingGoalCount()
The number of tests that are failing for the commit.
-
passingGoalCount
final Long passingGoalCount()
The number of tests that are passing for the commit.
-
status
final CommitListResponse.Item.Status status()
The commit status. Initially, the commit is
queued, then, it switches torunning. Finally, it can bepaused,failed, orcompleted.
-
statusMessage
final Optional<String> statusMessage()
The commit status message.
-
storageUri
final String storageUri()
The storage URI where the commit bundle is stored.
-
totalGoalCount
final Long totalGoalCount()
The total number of tests for the commit.
-
trainingDatasetId
final Optional<String> trainingDatasetId()
The training dataset id.
-
validationDatasetId
final Optional<String> validationDatasetId()
The validation dataset id.
-
deploymentStatus
final Optional<String> deploymentStatus()
The deployment status associated with the commit's model.
-
links
final Optional<CommitListResponse.Item.Links> links()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_commit
final JsonField<CommitListResponse.Item.Commit> _commit()
Returns the raw JSON value of commit.
Unlike commit, this method doesn't throw if the JSON field has an unexpected type.
-
_dateArchived
final JsonField<OffsetDateTime> _dateArchived()
Returns the raw JSON value of dateArchived.
Unlike dateArchived, this method doesn't throw if the JSON field has an unexpected type.
-
_dateCreated
final JsonField<OffsetDateTime> _dateCreated()
Returns the raw JSON value of dateCreated.
Unlike dateCreated, this method doesn't throw if the JSON field has an unexpected type.
-
_failingGoalCount
final JsonField<Long> _failingGoalCount()
Returns the raw JSON value of failingGoalCount.
Unlike failingGoalCount, this method doesn't throw if the JSON field has an unexpected type.
-
_mlModelId
final JsonField<String> _mlModelId()
Returns the raw JSON value of mlModelId.
Unlike mlModelId, this method doesn't throw if the JSON field has an unexpected type.
-
_passingGoalCount
final JsonField<Long> _passingGoalCount()
Returns the raw JSON value of passingGoalCount.
Unlike passingGoalCount, this method doesn't throw if the JSON field has an unexpected type.
-
_projectId
final JsonField<String> _projectId()
Returns the raw JSON value of projectId.
Unlike projectId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<CommitListResponse.Item.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_statusMessage
final JsonField<String> _statusMessage()
Returns the raw JSON value of statusMessage.
Unlike statusMessage, this method doesn't throw if the JSON field has an unexpected type.
-
_storageUri
final JsonField<String> _storageUri()
Returns the raw JSON value of storageUri.
Unlike storageUri, this method doesn't throw if the JSON field has an unexpected type.
-
_totalGoalCount
final JsonField<Long> _totalGoalCount()
Returns the raw JSON value of totalGoalCount.
Unlike totalGoalCount, this method doesn't throw if the JSON field has an unexpected type.
-
_trainingDatasetId
final JsonField<String> _trainingDatasetId()
Returns the raw JSON value of trainingDatasetId.
Unlike trainingDatasetId, this method doesn't throw if the JSON field has an unexpected type.
-
_validationDatasetId
final JsonField<String> _validationDatasetId()
Returns the raw JSON value of validationDatasetId.
Unlike validationDatasetId, this method doesn't throw if the JSON field has an unexpected type.
-
_archived
final JsonField<Boolean> _archived()
Returns the raw JSON value of archived.
Unlike archived, this method doesn't throw if the JSON field has an unexpected type.
-
_deploymentStatus
final JsonField<String> _deploymentStatus()
Returns the raw JSON value of deploymentStatus.
Unlike deploymentStatus, this method doesn't throw if the JSON field has an unexpected type.
-
_links
final JsonField<CommitListResponse.Item.Links> _links()
Returns the raw JSON value of links.
Unlike links, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CommitListResponse.Item.Builder toBuilder()
-
validate
final CommitListResponse.Item validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CommitListResponse.Item.Builder builder()
Returns a mutable builder for constructing an instance of Item.
The following fields are required:
.id() .commit() .dateArchived() .dateCreated() .failingGoalCount() .mlModelId() .passingGoalCount() .projectId() .status() .statusMessage() .storageUri() .totalGoalCount() .trainingDatasetId() .validationDatasetId()
-
-
-
-