Class CommitListResponse.Item.Commit
-
- All Implemented Interfaces:
public final class CommitListResponse.Item.CommitThe details of a commit (project version).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classCommitListResponse.Item.Commit.BuilderA builder for Commit.
-
Method Summary
Modifier and Type Method Description final Stringid()The commit id. final StringauthorId()The author id of the commit. final Optional<Long>fileSize()The size of the commit bundle in bytes. final Stringmessage()The commit message. final Optional<String>mlModelId()The model id. final StringstorageUri()The storage URI where the commit bundle is stored. final Optional<String>trainingDatasetId()The training dataset id. final Optional<String>validationDatasetId()The validation dataset id. final Optional<OffsetDateTime>dateCreated()The commit creation date. final Optional<String>gitCommitRef()The ref of the corresponding git commit. final Optional<Long>gitCommitSha()The SHA of the corresponding git commit. final Optional<String>gitCommitUrl()The URL of the corresponding git commit. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_authorId()Returns the raw JSON value of authorId. final JsonField<Long>_fileSize()Returns the raw JSON value of fileSize. final JsonField<String>_message()Returns the raw JSON value of message. final JsonField<String>_mlModelId()Returns the raw JSON value of mlModelId. final JsonField<String>_storageUri()Returns the raw JSON value of storageUri. final JsonField<String>_trainingDatasetId()Returns the raw JSON value of trainingDatasetId. final JsonField<String>_validationDatasetId()Returns the raw JSON value of validationDatasetId. final JsonField<OffsetDateTime>_dateCreated()Returns the raw JSON value of dateCreated. final JsonField<String>_gitCommitRef()Returns the raw JSON value of gitCommitRef. final JsonField<Long>_gitCommitSha()Returns the raw JSON value of gitCommitSha. final JsonField<String>_gitCommitUrl()Returns the raw JSON value of gitCommitUrl. final Map<String, JsonValue>_additionalProperties()final CommitListResponse.Item.Commit.BuildertoBuilder()final CommitListResponse.Item.Commitvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static CommitListResponse.Item.Commit.Builderbuilder()Returns a mutable builder for constructing an instance of Commit. -
-
Method Detail
-
storageUri
final String storageUri()
The storage URI where the commit bundle is stored.
-
trainingDatasetId
final Optional<String> trainingDatasetId()
The training dataset id.
-
validationDatasetId
final Optional<String> validationDatasetId()
The validation dataset id.
-
dateCreated
final Optional<OffsetDateTime> dateCreated()
The commit creation date.
-
gitCommitRef
final Optional<String> gitCommitRef()
The ref of the corresponding git commit.
-
gitCommitSha
final Optional<Long> gitCommitSha()
The SHA of the corresponding git commit.
-
gitCommitUrl
final Optional<String> gitCommitUrl()
The URL of the corresponding git commit.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_authorId
final JsonField<String> _authorId()
Returns the raw JSON value of authorId.
Unlike authorId, this method doesn't throw if the JSON field has an unexpected type.
-
_fileSize
final JsonField<Long> _fileSize()
Returns the raw JSON value of fileSize.
Unlike fileSize, this method doesn't throw if the JSON field has an unexpected type.
-
_message
final JsonField<String> _message()
Returns the raw JSON value of message.
Unlike message, this method doesn't throw if the JSON field has an unexpected type.
-
_mlModelId
final JsonField<String> _mlModelId()
Returns the raw JSON value of mlModelId.
Unlike mlModelId, this method doesn't throw if the JSON field has an unexpected type.
-
_storageUri
final JsonField<String> _storageUri()
Returns the raw JSON value of storageUri.
Unlike storageUri, this method doesn't throw if the JSON field has an unexpected type.
-
_trainingDatasetId
final JsonField<String> _trainingDatasetId()
Returns the raw JSON value of trainingDatasetId.
Unlike trainingDatasetId, this method doesn't throw if the JSON field has an unexpected type.
-
_validationDatasetId
final JsonField<String> _validationDatasetId()
Returns the raw JSON value of validationDatasetId.
Unlike validationDatasetId, this method doesn't throw if the JSON field has an unexpected type.
-
_dateCreated
final JsonField<OffsetDateTime> _dateCreated()
Returns the raw JSON value of dateCreated.
Unlike dateCreated, this method doesn't throw if the JSON field has an unexpected type.
-
_gitCommitRef
final JsonField<String> _gitCommitRef()
Returns the raw JSON value of gitCommitRef.
Unlike gitCommitRef, this method doesn't throw if the JSON field has an unexpected type.
-
_gitCommitSha
final JsonField<Long> _gitCommitSha()
Returns the raw JSON value of gitCommitSha.
Unlike gitCommitSha, this method doesn't throw if the JSON field has an unexpected type.
-
_gitCommitUrl
final JsonField<String> _gitCommitUrl()
Returns the raw JSON value of gitCommitUrl.
Unlike gitCommitUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final CommitListResponse.Item.Commit.Builder toBuilder()
-
validate
final CommitListResponse.Item.Commit validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static CommitListResponse.Item.Commit.Builder builder()
Returns a mutable builder for constructing an instance of Commit.
The following fields are required:
.id() .authorId() .fileSize() .message() .mlModelId() .storageUri() .trainingDatasetId() .validationDatasetId()
-
-
-
-