Class InferencePipelineCreateParams.DataBackend.BigQueryDataBackend
-
- All Implemented Interfaces:
public final class InferencePipelineCreateParams.DataBackend.BigQueryDataBackend
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineCreateParams.DataBackend.BigQueryDataBackend.BuilderA builder for BigQueryDataBackend.
public final classInferencePipelineCreateParams.DataBackend.BigQueryDataBackend.BackendTypepublic final classInferencePipelineCreateParams.DataBackend.BigQueryDataBackend.Configpublic final classInferencePipelineCreateParams.DataBackend.BigQueryDataBackend.PartitionType
-
Method Summary
-
-
Method Detail
-
backendType
final InferencePipelineCreateParams.DataBackend.BigQueryDataBackend.BackendType backendType()
-
bigqueryConnectionId
final Optional<String> bigqueryConnectionId()
-
bodyProjectId
final String bodyProjectId()
-
partitionType
final Optional<InferencePipelineCreateParams.DataBackend.BigQueryDataBackend.PartitionType> partitionType()
-
_backendType
final JsonField<InferencePipelineCreateParams.DataBackend.BigQueryDataBackend.BackendType> _backendType()
Returns the raw JSON value of backendType.
Unlike backendType, this method doesn't throw if the JSON field has an unexpected type.
-
_bigqueryConnectionId
final JsonField<String> _bigqueryConnectionId()
Returns the raw JSON value of bigqueryConnectionId.
Unlike bigqueryConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_config
final JsonField<InferencePipelineCreateParams.DataBackend.BigQueryDataBackend.Config> _config()
Returns the raw JSON value of config.
Unlike config, this method doesn't throw if the JSON field has an unexpected type.
-
_datasetId
final JsonField<String> _datasetId()
Returns the raw JSON value of datasetId.
Unlike datasetId, this method doesn't throw if the JSON field has an unexpected type.
-
_bodyProjectId
final JsonField<String> _bodyProjectId()
Returns the raw JSON value of bodyProjectId.
Unlike bodyProjectId, this method doesn't throw if the JSON field has an unexpected type.
-
_tableId
final JsonField<String> _tableId()
Returns the raw JSON value of tableId.
Unlike tableId, this method doesn't throw if the JSON field has an unexpected type.
-
_partitionType
final JsonField<InferencePipelineCreateParams.DataBackend.BigQueryDataBackend.PartitionType> _partitionType()
Returns the raw JSON value of partitionType.
Unlike partitionType, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InferencePipelineCreateParams.DataBackend.BigQueryDataBackend validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineCreateParams.DataBackend.BigQueryDataBackend.Builder builder()
Returns a mutable builder for constructing an instance of BigQueryDataBackend.
The following fields are required:
.backendType() .bigqueryConnectionId() .config() .datasetId() .bodyProjectId() .tableId()
-
-
-
-