Class InferencePipelineCreateParams.Workspace.MonthlyUsage
-
- All Implemented Interfaces:
public final class InferencePipelineCreateParams.Workspace.MonthlyUsage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineCreateParams.Workspace.MonthlyUsage.BuilderA builder for MonthlyUsage.
-
Method Summary
Modifier and Type Method Description final Optional<Long>executionTimeMs()final Optional<LocalDate>monthYear()final Optional<Long>predictionCount()final JsonField<Long>_executionTimeMs()Returns the raw JSON value of executionTimeMs. final JsonField<LocalDate>_monthYear()Returns the raw JSON value of monthYear. final JsonField<Long>_predictionCount()Returns the raw JSON value of predictionCount. final Map<String, JsonValue>_additionalProperties()final InferencePipelineCreateParams.Workspace.MonthlyUsage.BuildertoBuilder()final InferencePipelineCreateParams.Workspace.MonthlyUsagevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InferencePipelineCreateParams.Workspace.MonthlyUsage.Builderbuilder()Returns a mutable builder for constructing an instance of MonthlyUsage. -
-
Method Detail
-
executionTimeMs
final Optional<Long> executionTimeMs()
-
predictionCount
final Optional<Long> predictionCount()
-
_executionTimeMs
final JsonField<Long> _executionTimeMs()
Returns the raw JSON value of executionTimeMs.
Unlike executionTimeMs, this method doesn't throw if the JSON field has an unexpected type.
-
_monthYear
final JsonField<LocalDate> _monthYear()
Returns the raw JSON value of monthYear.
Unlike monthYear, this method doesn't throw if the JSON field has an unexpected type.
-
_predictionCount
final JsonField<Long> _predictionCount()
Returns the raw JSON value of predictionCount.
Unlike predictionCount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineCreateParams.Workspace.MonthlyUsage.Builder toBuilder()
-
validate
final InferencePipelineCreateParams.Workspace.MonthlyUsage validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineCreateParams.Workspace.MonthlyUsage.Builder builder()
Returns a mutable builder for constructing an instance of MonthlyUsage.
-
-
-
-