Class InferencePipelineCreateResponse.DataBackend.DatabricksDtlDataBackend
-
- All Implemented Interfaces:
public final class InferencePipelineCreateResponse.DataBackend.DatabricksDtlDataBackend
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineCreateResponse.DataBackend.DatabricksDtlDataBackend.BuilderA builder for DatabricksDtlDataBackend.
public final classInferencePipelineCreateResponse.DataBackend.DatabricksDtlDataBackend.BackendTypepublic final classInferencePipelineCreateResponse.DataBackend.DatabricksDtlDataBackend.Config
-
Method Summary
-
-
Method Detail
-
backendType
final InferencePipelineCreateResponse.DataBackend.DatabricksDtlDataBackend.BackendType backendType()
-
databricksDtlConnectionId
final Optional<String> databricksDtlConnectionId()
-
_backendType
final JsonField<InferencePipelineCreateResponse.DataBackend.DatabricksDtlDataBackend.BackendType> _backendType()
Returns the raw JSON value of backendType.
Unlike backendType, this method doesn't throw if the JSON field has an unexpected type.
-
_config
final JsonField<InferencePipelineCreateResponse.DataBackend.DatabricksDtlDataBackend.Config> _config()
Returns the raw JSON value of config.
Unlike config, this method doesn't throw if the JSON field has an unexpected type.
-
_databricksDtlConnectionId
final JsonField<String> _databricksDtlConnectionId()
Returns the raw JSON value of databricksDtlConnectionId.
Unlike databricksDtlConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_tableId
final JsonField<String> _tableId()
Returns the raw JSON value of tableId.
Unlike tableId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineCreateResponse.DataBackend.DatabricksDtlDataBackend.Builder toBuilder()
-
validate
final InferencePipelineCreateResponse.DataBackend.DatabricksDtlDataBackend validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineCreateResponse.DataBackend.DatabricksDtlDataBackend.Builder builder()
Returns a mutable builder for constructing an instance of DatabricksDtlDataBackend.
The following fields are required:
.backendType() .config() .databricksDtlConnectionId() .tableId()
-
-
-
-