Class InferencePipelineCreateResponse.DataBackend.RedshiftDataBackend
-
- All Implemented Interfaces:
public final class InferencePipelineCreateResponse.DataBackend.RedshiftDataBackend
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineCreateResponse.DataBackend.RedshiftDataBackend.BuilderA builder for RedshiftDataBackend.
public final classInferencePipelineCreateResponse.DataBackend.RedshiftDataBackend.BackendTypepublic final classInferencePipelineCreateResponse.DataBackend.RedshiftDataBackend.Config
-
Method Summary
-
-
Method Detail
-
backendType
final InferencePipelineCreateResponse.DataBackend.RedshiftDataBackend.BackendType backendType()
-
redshiftConnectionId
final Optional<String> redshiftConnectionId()
-
schemaName
final String schemaName()
-
_backendType
final JsonField<InferencePipelineCreateResponse.DataBackend.RedshiftDataBackend.BackendType> _backendType()
Returns the raw JSON value of backendType.
Unlike backendType, this method doesn't throw if the JSON field has an unexpected type.
-
_config
final JsonField<InferencePipelineCreateResponse.DataBackend.RedshiftDataBackend.Config> _config()
Returns the raw JSON value of config.
Unlike config, this method doesn't throw if the JSON field has an unexpected type.
-
_redshiftConnectionId
final JsonField<String> _redshiftConnectionId()
Returns the raw JSON value of redshiftConnectionId.
Unlike redshiftConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_schemaName
final JsonField<String> _schemaName()
Returns the raw JSON value of schemaName.
Unlike schemaName, this method doesn't throw if the JSON field has an unexpected type.
-
_tableName
final JsonField<String> _tableName()
Returns the raw JSON value of tableName.
Unlike tableName, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
validate
final InferencePipelineCreateResponse.DataBackend.RedshiftDataBackend validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineCreateResponse.DataBackend.RedshiftDataBackend.Builder builder()
Returns a mutable builder for constructing an instance of RedshiftDataBackend.
The following fields are required:
.backendType() .config() .redshiftConnectionId() .schemaName() .tableName()
-
-
-
-