Class InferencePipelineCreateResponse.Links
-
- All Implemented Interfaces:
public final class InferencePipelineCreateResponse.Links
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineCreateResponse.Links.BuilderA builder for Links.
-
Method Summary
Modifier and Type Method Description final Stringapp()final JsonField<String>_app()Returns the raw JSON value of app. final Map<String, JsonValue>_additionalProperties()final InferencePipelineCreateResponse.Links.BuildertoBuilder()final InferencePipelineCreateResponse.Linksvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InferencePipelineCreateResponse.Links.Builderbuilder()Returns a mutable builder for constructing an instance of Links. -
-
Method Detail
-
_app
final JsonField<String> _app()
Returns the raw JSON value of app.
Unlike app, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineCreateResponse.Links.Builder toBuilder()
-
validate
final InferencePipelineCreateResponse.Links validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineCreateResponse.Links.Builder builder()
Returns a mutable builder for constructing an instance of Links.
The following fields are required:
.app()
-
-
-
-