Class InferencePipelineListResponse.Item.DataBackend.DatabricksDtlDataBackend
-
- All Implemented Interfaces:
public final class InferencePipelineListResponse.Item.DataBackend.DatabricksDtlDataBackend
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineListResponse.Item.DataBackend.DatabricksDtlDataBackend.BuilderA builder for DatabricksDtlDataBackend.
public final classInferencePipelineListResponse.Item.DataBackend.DatabricksDtlDataBackend.BackendTypepublic final classInferencePipelineListResponse.Item.DataBackend.DatabricksDtlDataBackend.Config
-
Method Summary
-
-
Method Detail
-
backendType
final InferencePipelineListResponse.Item.DataBackend.DatabricksDtlDataBackend.BackendType backendType()
-
config
final InferencePipelineListResponse.Item.DataBackend.DatabricksDtlDataBackend.Config config()
-
databricksDtlConnectionId
final Optional<String> databricksDtlConnectionId()
-
_backendType
final JsonField<InferencePipelineListResponse.Item.DataBackend.DatabricksDtlDataBackend.BackendType> _backendType()
Returns the raw JSON value of backendType.
Unlike backendType, this method doesn't throw if the JSON field has an unexpected type.
-
_config
final JsonField<InferencePipelineListResponse.Item.DataBackend.DatabricksDtlDataBackend.Config> _config()
Returns the raw JSON value of config.
Unlike config, this method doesn't throw if the JSON field has an unexpected type.
-
_databricksDtlConnectionId
final JsonField<String> _databricksDtlConnectionId()
Returns the raw JSON value of databricksDtlConnectionId.
Unlike databricksDtlConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_tableId
final JsonField<String> _tableId()
Returns the raw JSON value of tableId.
Unlike tableId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineListResponse.Item.DataBackend.DatabricksDtlDataBackend.Builder toBuilder()
-
validate
final InferencePipelineListResponse.Item.DataBackend.DatabricksDtlDataBackend validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineListResponse.Item.DataBackend.DatabricksDtlDataBackend.Builder builder()
Returns a mutable builder for constructing an instance of DatabricksDtlDataBackend.
The following fields are required:
.backendType() .config() .databricksDtlConnectionId() .tableId()
-
-
-
-