Class InferencePipelineListResponse.Item.DataBackend.PostgresDataBackend
-
- All Implemented Interfaces:
public final class InferencePipelineListResponse.Item.DataBackend.PostgresDataBackend
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineListResponse.Item.DataBackend.PostgresDataBackend.BuilderA builder for PostgresDataBackend.
public final classInferencePipelineListResponse.Item.DataBackend.PostgresDataBackend.BackendTypepublic final classInferencePipelineListResponse.Item.DataBackend.PostgresDataBackend.Config
-
Method Summary
-
-
Method Detail
-
backendType
final InferencePipelineListResponse.Item.DataBackend.PostgresDataBackend.BackendType backendType()
-
postgresConnectionId
final Optional<String> postgresConnectionId()
-
_backendType
final JsonField<InferencePipelineListResponse.Item.DataBackend.PostgresDataBackend.BackendType> _backendType()
Returns the raw JSON value of backendType.
Unlike backendType, this method doesn't throw if the JSON field has an unexpected type.
-
_config
final JsonField<InferencePipelineListResponse.Item.DataBackend.PostgresDataBackend.Config> _config()
Returns the raw JSON value of config.
Unlike config, this method doesn't throw if the JSON field has an unexpected type.
-
_database
final JsonField<String> _database()
Returns the raw JSON value of database.
Unlike database, this method doesn't throw if the JSON field has an unexpected type.
-
_postgresConnectionId
final JsonField<String> _postgresConnectionId()
Returns the raw JSON value of postgresConnectionId.
Unlike postgresConnectionId, this method doesn't throw if the JSON field has an unexpected type.
-
_schema
final JsonField<String> _schema()
Returns the raw JSON value of schema.
Unlike schema, this method doesn't throw if the JSON field has an unexpected type.
-
_table
final JsonField<String> _table()
Returns the raw JSON value of table.
Unlike table, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InferencePipelineListResponse.Item.DataBackend.PostgresDataBackend.Builder toBuilder()
-
validate
final InferencePipelineListResponse.Item.DataBackend.PostgresDataBackend validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InferencePipelineListResponse.Item.DataBackend.PostgresDataBackend.Builder builder()
Returns a mutable builder for constructing an instance of PostgresDataBackend.
The following fields are required:
.backendType() .config() .database() .postgresConnectionId() .schema() .table()
-
-
-
-