Class TestListResponse
-
- All Implemented Interfaces:
public final class TestListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTestListResponse.BuilderA builder for TestListResponse.
public final classTestListResponse.Item
-
Method Summary
Modifier and Type Method Description final List<TestListResponse.Item>items()final JsonField<List<TestListResponse.Item>>_items()Returns the raw JSON value of items. final Map<String, JsonValue>_additionalProperties()final TestListResponse.BuildertoBuilder()final TestListResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TestListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TestListResponse. -
-
Method Detail
-
items
final List<TestListResponse.Item> items()
-
_items
final JsonField<List<TestListResponse.Item>> _items()
Returns the raw JSON value of items.
Unlike items, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TestListResponse.Builder toBuilder()
-
validate
final TestListResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TestListResponse.Builder builder()
Returns a mutable builder for constructing an instance of TestListResponse.
The following fields are required:
.items()
-
-
-
-