Class TestListResponse.Item.Threshold.InsightParameter
-
- All Implemented Interfaces:
public final class TestListResponse.Item.Threshold.InsightParameter
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTestListResponse.Item.Threshold.InsightParameter.BuilderA builder for InsightParameter.
-
Method Summary
Modifier and Type Method Description final Stringname()The name of the insight filter. final JsonValue_value()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = insightParameter.value().convert(MyClass.class);final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final TestListResponse.Item.Threshold.InsightParameter.BuildertoBuilder()final TestListResponse.Item.Threshold.InsightParametervalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TestListResponse.Item.Threshold.InsightParameter.Builderbuilder()Returns a mutable builder for constructing an instance of InsightParameter. -
-
Method Detail
-
_value
final JsonValue _value()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = insightParameter.value().convert(MyClass.class);
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TestListResponse.Item.Threshold.InsightParameter.Builder toBuilder()
-
validate
final TestListResponse.Item.Threshold.InsightParameter validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TestListResponse.Item.Threshold.InsightParameter.Builder builder()
Returns a mutable builder for constructing an instance of InsightParameter.
The following fields are required:
.name() .value()
-
-
-
-