Class TestListResponse.Item.Threshold.Value
-
- All Implemented Interfaces:
public final class TestListResponse.Item.Threshold.ValueThe value to be compared.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceTestListResponse.Item.Threshold.Value.VisitorAn interface that defines how to map each variant of Value to a value of type T.
-
Method Summary
-
-
Method Detail
-
accept
final <T extends Any> T accept(TestListResponse.Item.Threshold.Value.Visitor<T> visitor)
Maps this instance's current variant to a value of type T using the given visitor.
Note that this method is not forwards compatible with new variants from the API, unless visitor overrides Visitor.unknown. To handle variants not known to this version of the SDK gracefully, consider overriding Visitor.unknown:
import com.openlayer.api.core.JsonValue; import java.util.Optional; Optional<String> result = value.accept(new Value.Visitor<Optional<String>>() { @Override public Optional<String> visitNumber(Double number) { return Optional.of(number.toString()); } // ... @Override public Optional<String> unknown(JsonValue json) { // Or inspect the `json`. return Optional.empty(); } });
-
validate
final TestListResponse.Item.Threshold.Value validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
ofNumber
final static TestListResponse.Item.Threshold.Value ofNumber(Double number)
-
ofBool
final static TestListResponse.Item.Threshold.Value ofBool(Boolean bool)
-
ofString
final static TestListResponse.Item.Threshold.Value ofString(String string)
-
ofStrings
final static TestListResponse.Item.Threshold.Value ofStrings(List<String> strings)
-
-
-
-