Class TestUpdateParams.Body
-
- All Implemented Interfaces:
public final class TestUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTestUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final List<TestUpdateParams.Payload>payloads()final JsonField<List<TestUpdateParams.Payload>>_payloads()Returns the raw JSON value of payloads. final Map<String, JsonValue>_additionalProperties()final TestUpdateParams.Body.BuildertoBuilder()final TestUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TestUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
payloads
final List<TestUpdateParams.Payload> payloads()
-
_payloads
final JsonField<List<TestUpdateParams.Payload>> _payloads()
Returns the raw JSON value of payloads.
Unlike payloads, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TestUpdateParams.Body.Builder toBuilder()
-
validate
final TestUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TestUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.payloads()
-
-
-
-