Class TestUpdateParams.Payload
-
- All Implemented Interfaces:
public final class TestUpdateParams.Payload
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTestUpdateParams.Payload.BuilderA builder for Payload.
public final classTestUpdateParams.Payload.Suggestedpublic final classTestUpdateParams.Payload.Threshold
-
Method Summary
Modifier and Type Method Description final Stringid()final Optional<Boolean>archived()Whether the test is archived. final JsonValue_description()The test description. final Optional<String>name()The test name. final Optional<TestUpdateParams.Payload.Suggested>suggested()final Optional<List<TestUpdateParams.Payload.Threshold>>thresholds()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<Boolean>_archived()Returns the raw JSON value of archived. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<TestUpdateParams.Payload.Suggested>_suggested()Returns the raw JSON value of suggested. final JsonField<List<TestUpdateParams.Payload.Threshold>>_thresholds()Returns the raw JSON value of thresholds. final Map<String, JsonValue>_additionalProperties()final TestUpdateParams.Payload.BuildertoBuilder()final TestUpdateParams.Payloadvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TestUpdateParams.Payload.Builderbuilder()Returns a mutable builder for constructing an instance of Payload. -
-
Method Detail
-
_description
final JsonValue _description()
The test description.
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = payload.description().convert(MyClass.class);
-
suggested
final Optional<TestUpdateParams.Payload.Suggested> suggested()
-
thresholds
final Optional<List<TestUpdateParams.Payload.Threshold>> thresholds()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_archived
final JsonField<Boolean> _archived()
Returns the raw JSON value of archived.
Unlike archived, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_suggested
final JsonField<TestUpdateParams.Payload.Suggested> _suggested()
Returns the raw JSON value of suggested.
Unlike suggested, this method doesn't throw if the JSON field has an unexpected type.
-
_thresholds
final JsonField<List<TestUpdateParams.Payload.Threshold>> _thresholds()
Returns the raw JSON value of thresholds.
Unlike thresholds, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TestUpdateParams.Payload.Builder toBuilder()
-
validate
final TestUpdateParams.Payload validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TestUpdateParams.Payload.Builder builder()
Returns a mutable builder for constructing an instance of Payload.
The following fields are required:
.id()
-
-
-
-