Class TestUpdateResponse
-
- All Implemented Interfaces:
public final class TestUpdateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTestUpdateResponse.BuilderA builder for TestUpdateResponse.
-
Method Summary
Modifier and Type Method Description final Optional<String>taskResultId()final Optional<String>taskResultUrl()final JsonField<String>_taskResultId()Returns the raw JSON value of taskResultId. final JsonField<String>_taskResultUrl()Returns the raw JSON value of taskResultUrl. final Map<String, JsonValue>_additionalProperties()final TestUpdateResponse.BuildertoBuilder()final TestUpdateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TestUpdateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of TestUpdateResponse. -
-
Method Detail
-
taskResultId
final Optional<String> taskResultId()
-
taskResultUrl
final Optional<String> taskResultUrl()
-
_taskResultId
final JsonField<String> _taskResultId()
Returns the raw JSON value of taskResultId.
Unlike taskResultId, this method doesn't throw if the JSON field has an unexpected type.
-
_taskResultUrl
final JsonField<String> _taskResultUrl()
Returns the raw JSON value of taskResultUrl.
Unlike taskResultUrl, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TestUpdateResponse.Builder toBuilder()
-
validate
final TestUpdateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TestUpdateResponse.Builder builder()
Returns a mutable builder for constructing an instance of TestUpdateResponse.
-
-
-
-