Class PresignedUrlCreateResponse
-
- All Implemented Interfaces:
public final class PresignedUrlCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classPresignedUrlCreateResponse.BuilderA builder for PresignedUrlCreateResponse.
-
Method Summary
Modifier and Type Method Description final StringstorageUri()The storage URI to send back to the backend after the upload was completed. final Stringurl()The presigned url. final JsonValue_fields()Fields to include in the body of the upload. final JsonField<String>_storageUri()Returns the raw JSON value of storageUri. final JsonField<String>_url()Returns the raw JSON value of url. final Map<String, JsonValue>_additionalProperties()final PresignedUrlCreateResponse.BuildertoBuilder()final PresignedUrlCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static PresignedUrlCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of PresignedUrlCreateResponse. -
-
Method Detail
-
storageUri
final String storageUri()
The storage URI to send back to the backend after the upload was completed.
-
_fields
final JsonValue _fields()
Fields to include in the body of the upload. Only needed by s3
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = presignedUrlCreateResponse.fields().convert(MyClass.class);
-
_storageUri
final JsonField<String> _storageUri()
Returns the raw JSON value of storageUri.
Unlike storageUri, this method doesn't throw if the JSON field has an unexpected type.
-
_url
final JsonField<String> _url()
Returns the raw JSON value of url.
Unlike url, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final PresignedUrlCreateResponse.Builder toBuilder()
-
validate
final PresignedUrlCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static PresignedUrlCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of PresignedUrlCreateResponse.
The following fields are required:
.storageUri() .url()
-
-
-
-