Class TestEvaluateParams.Body
-
- All Implemented Interfaces:
public final class TestEvaluateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTestEvaluateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final LongendTimestamp()End timestamp in seconds (Unix epoch) final LongstartTimestamp()Start timestamp in seconds (Unix epoch) final Optional<String>inferencePipelineId()ID of the inference pipeline to evaluate. final Optional<Boolean>overwriteResults()Whether to overwrite existing test results final JsonField<Long>_endTimestamp()Returns the raw JSON value of endTimestamp. final JsonField<Long>_startTimestamp()Returns the raw JSON value of startTimestamp. final JsonField<String>_inferencePipelineId()Returns the raw JSON value of inferencePipelineId. final JsonField<Boolean>_overwriteResults()Returns the raw JSON value of overwriteResults. final Map<String, JsonValue>_additionalProperties()final TestEvaluateParams.Body.BuildertoBuilder()final TestEvaluateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TestEvaluateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
endTimestamp
final Long endTimestamp()
End timestamp in seconds (Unix epoch)
-
startTimestamp
final Long startTimestamp()
Start timestamp in seconds (Unix epoch)
-
inferencePipelineId
final Optional<String> inferencePipelineId()
ID of the inference pipeline to evaluate. If not provided, all inference pipelines the test applies to will be evaluated.
-
overwriteResults
final Optional<Boolean> overwriteResults()
Whether to overwrite existing test results
-
_endTimestamp
final JsonField<Long> _endTimestamp()
Returns the raw JSON value of endTimestamp.
Unlike endTimestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_startTimestamp
final JsonField<Long> _startTimestamp()
Returns the raw JSON value of startTimestamp.
Unlike startTimestamp, this method doesn't throw if the JSON field has an unexpected type.
-
_inferencePipelineId
final JsonField<String> _inferencePipelineId()
Returns the raw JSON value of inferencePipelineId.
Unlike inferencePipelineId, this method doesn't throw if the JSON field has an unexpected type.
-
_overwriteResults
final JsonField<Boolean> _overwriteResults()
Returns the raw JSON value of overwriteResults.
Unlike overwriteResults, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TestEvaluateParams.Body.Builder toBuilder()
-
validate
final TestEvaluateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TestEvaluateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
The following fields are required:
.endTimestamp() .startTimestamp()
-
-
-
-