Class TestListResultsResponse.Item
-
- All Implemented Interfaces:
public final class TestListResultsResponse.Item
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTestListResultsResponse.Item.BuilderA builder for Item.
public final classTestListResultsResponse.Item.StatusThe status of the test.
public final classTestListResultsResponse.Item.ExpectedValuepublic final classTestListResultsResponse.Item.Goalpublic final classTestListResultsResponse.Item.RowsBodyThe body of the rows request.
-
Method Summary
-
-
Method Detail
-
dateCreated
final OffsetDateTime dateCreated()
The creation date.
-
dateDataEnds
final Optional<OffsetDateTime> dateDataEnds()
The data end date.
-
dateDataStarts
final Optional<OffsetDateTime> dateDataStarts()
The data start date.
-
dateUpdated
final OffsetDateTime dateUpdated()
The last updated date.
-
inferencePipelineId
final Optional<String> inferencePipelineId()
The inference pipeline id.
-
projectVersionId
final Optional<String> projectVersionId()
The project version (commit) id.
-
status
final TestListResultsResponse.Item.Status status()
The status of the test.
-
statusMessage
final Optional<String> statusMessage()
The status message.
-
expectedValues
final Optional<List<TestListResultsResponse.Item.ExpectedValue>> expectedValues()
-
goal
final Optional<TestListResultsResponse.Item.Goal> goal()
-
rowsBody
final Optional<TestListResultsResponse.Item.RowsBody> rowsBody()
The body of the rows request.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_dateCreated
final JsonField<OffsetDateTime> _dateCreated()
Returns the raw JSON value of dateCreated.
Unlike dateCreated, this method doesn't throw if the JSON field has an unexpected type.
-
_dateDataEnds
final JsonField<OffsetDateTime> _dateDataEnds()
Returns the raw JSON value of dateDataEnds.
Unlike dateDataEnds, this method doesn't throw if the JSON field has an unexpected type.
-
_dateDataStarts
final JsonField<OffsetDateTime> _dateDataStarts()
Returns the raw JSON value of dateDataStarts.
Unlike dateDataStarts, this method doesn't throw if the JSON field has an unexpected type.
-
_dateUpdated
final JsonField<OffsetDateTime> _dateUpdated()
Returns the raw JSON value of dateUpdated.
Unlike dateUpdated, this method doesn't throw if the JSON field has an unexpected type.
-
_inferencePipelineId
final JsonField<String> _inferencePipelineId()
Returns the raw JSON value of inferencePipelineId.
Unlike inferencePipelineId, this method doesn't throw if the JSON field has an unexpected type.
-
_projectVersionId
final JsonField<String> _projectVersionId()
Returns the raw JSON value of projectVersionId.
Unlike projectVersionId, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<TestListResultsResponse.Item.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_statusMessage
final JsonField<String> _statusMessage()
Returns the raw JSON value of statusMessage.
Unlike statusMessage, this method doesn't throw if the JSON field has an unexpected type.
-
_expectedValues
final JsonField<List<TestListResultsResponse.Item.ExpectedValue>> _expectedValues()
Returns the raw JSON value of expectedValues.
Unlike expectedValues, this method doesn't throw if the JSON field has an unexpected type.
-
_goal
final JsonField<TestListResultsResponse.Item.Goal> _goal()
Returns the raw JSON value of goal.
Unlike goal, this method doesn't throw if the JSON field has an unexpected type.
-
_goalId
final JsonField<String> _goalId()
Returns the raw JSON value of goalId.
Unlike goalId, this method doesn't throw if the JSON field has an unexpected type.
-
_rows
final JsonField<String> _rows()
Returns the raw JSON value of rows.
Unlike rows, this method doesn't throw if the JSON field has an unexpected type.
-
_rowsBody
final JsonField<TestListResultsResponse.Item.RowsBody> _rowsBody()
Returns the raw JSON value of rowsBody.
Unlike rowsBody, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TestListResultsResponse.Item.Builder toBuilder()
-
validate
final TestListResultsResponse.Item validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TestListResultsResponse.Item.Builder builder()
Returns a mutable builder for constructing an instance of Item.
The following fields are required:
.id() .dateCreated() .dateDataEnds() .dateDataStarts() .dateUpdated() .inferencePipelineId() .projectVersionId() .status() .statusMessage()
-
-
-
-