Class TestListResultsResponse.Item.ExpectedValue
-
- All Implemented Interfaces:
public final class TestListResultsResponse.Item.ExpectedValue
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTestListResultsResponse.Item.ExpectedValue.BuilderA builder for ExpectedValue.
-
Method Summary
Modifier and Type Method Description final Optional<Float>lowerThreshold()the lower threshold for the expected value final Optional<String>measurement()One of the measurementvalues in the test's thresholdsfinal Optional<Float>upperThreshold()The upper threshold for the expected value final JsonField<Float>_lowerThreshold()Returns the raw JSON value of lowerThreshold. final JsonField<String>_measurement()Returns the raw JSON value of measurement. final JsonField<Float>_upperThreshold()Returns the raw JSON value of upperThreshold. final Map<String, JsonValue>_additionalProperties()final TestListResultsResponse.Item.ExpectedValue.BuildertoBuilder()final TestListResultsResponse.Item.ExpectedValuevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static TestListResultsResponse.Item.ExpectedValue.Builderbuilder()Returns a mutable builder for constructing an instance of ExpectedValue. -
-
Method Detail
-
lowerThreshold
final Optional<Float> lowerThreshold()
the lower threshold for the expected value
-
measurement
final Optional<String> measurement()
One of the
measurementvalues in the test's thresholds
-
upperThreshold
final Optional<Float> upperThreshold()
The upper threshold for the expected value
-
_lowerThreshold
final JsonField<Float> _lowerThreshold()
Returns the raw JSON value of lowerThreshold.
Unlike lowerThreshold, this method doesn't throw if the JSON field has an unexpected type.
-
_measurement
final JsonField<String> _measurement()
Returns the raw JSON value of measurement.
Unlike measurement, this method doesn't throw if the JSON field has an unexpected type.
-
_upperThreshold
final JsonField<Float> _upperThreshold()
Returns the raw JSON value of upperThreshold.
Unlike upperThreshold, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TestListResultsResponse.Item.ExpectedValue.Builder toBuilder()
-
validate
final TestListResultsResponse.Item.ExpectedValue validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TestListResultsResponse.Item.ExpectedValue.Builder builder()
Returns a mutable builder for constructing an instance of ExpectedValue.
-
-
-
-