Class TestListResultsResponse.Item.Goal.Threshold
-
- All Implemented Interfaces:
public final class TestListResultsResponse.Item.Goal.Threshold
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classTestListResultsResponse.Item.Goal.Threshold.BuilderA builder for Threshold.
public final classTestListResultsResponse.Item.Goal.Threshold.InsightNameThe insight name to be evaluated.
public final classTestListResultsResponse.Item.Goal.Threshold.InsightParameterpublic final classTestListResultsResponse.Item.Goal.Threshold.OperatorThe operator to be used for the evaluation.
public final classTestListResultsResponse.Item.Goal.Threshold.ThresholdModeWhether to use automatic anomaly detection or manual thresholds
public final classTestListResultsResponse.Item.Goal.Threshold.ValueThe value to be compared.
-
Method Summary
-
-
Method Detail
-
insightName
final Optional<TestListResultsResponse.Item.Goal.Threshold.InsightName> insightName()
The insight name to be evaluated.
-
insightParameters
final Optional<List<TestListResultsResponse.Item.Goal.Threshold.InsightParameter>> insightParameters()
The insight parameters. Required only for some test subtypes. For example, for tests that require a column name, the insight parameters will be {'name': 'column_name', 'value': 'Age'}
-
measurement
final Optional<String> measurement()
The measurement to be evaluated.
-
operator
final Optional<TestListResultsResponse.Item.Goal.Threshold.Operator> operator()
The operator to be used for the evaluation.
-
thresholdMode
final Optional<TestListResultsResponse.Item.Goal.Threshold.ThresholdMode> thresholdMode()
Whether to use automatic anomaly detection or manual thresholds
-
value
final Optional<TestListResultsResponse.Item.Goal.Threshold.Value> value()
The value to be compared.
-
_insightName
final JsonField<TestListResultsResponse.Item.Goal.Threshold.InsightName> _insightName()
Returns the raw JSON value of insightName.
Unlike insightName, this method doesn't throw if the JSON field has an unexpected type.
-
_insightParameters
final JsonField<List<TestListResultsResponse.Item.Goal.Threshold.InsightParameter>> _insightParameters()
Returns the raw JSON value of insightParameters.
Unlike insightParameters, this method doesn't throw if the JSON field has an unexpected type.
-
_measurement
final JsonField<String> _measurement()
Returns the raw JSON value of measurement.
Unlike measurement, this method doesn't throw if the JSON field has an unexpected type.
-
_operator
final JsonField<TestListResultsResponse.Item.Goal.Threshold.Operator> _operator()
Returns the raw JSON value of operator.
Unlike operator, this method doesn't throw if the JSON field has an unexpected type.
-
_thresholdMode
final JsonField<TestListResultsResponse.Item.Goal.Threshold.ThresholdMode> _thresholdMode()
Returns the raw JSON value of thresholdMode.
Unlike thresholdMode, this method doesn't throw if the JSON field has an unexpected type.
-
_value
final JsonField<TestListResultsResponse.Item.Goal.Threshold.Value> _value()
Returns the raw JSON value of value.
Unlike value, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final TestListResultsResponse.Item.Goal.Threshold.Builder toBuilder()
-
validate
final TestListResultsResponse.Item.Goal.Threshold validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static TestListResultsResponse.Item.Goal.Threshold.Builder builder()
Returns a mutable builder for constructing an instance of Threshold.
-
-
-
-