Class WorkspaceUpdateParams.Body
-
- All Implemented Interfaces:
public final class WorkspaceUpdateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkspaceUpdateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<String>inviteCode()The workspace invite code. final Optional<String>name()The workspace name. final Optional<String>slug()The workspace slug. final JsonField<String>_inviteCode()Returns the raw JSON value of inviteCode. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_slug()Returns the raw JSON value of slug. final Map<String, JsonValue>_additionalProperties()final WorkspaceUpdateParams.Body.BuildertoBuilder()final WorkspaceUpdateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WorkspaceUpdateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
inviteCode
final Optional<String> inviteCode()
The workspace invite code.
-
_inviteCode
final JsonField<String> _inviteCode()
Returns the raw JSON value of inviteCode.
Unlike inviteCode, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_slug
final JsonField<String> _slug()
Returns the raw JSON value of slug.
Unlike slug, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WorkspaceUpdateParams.Body.Builder toBuilder()
-
validate
final WorkspaceUpdateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WorkspaceUpdateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-