Class WorkspaceUpdateResponse.MonthlyUsage
-
- All Implemented Interfaces:
public final class WorkspaceUpdateResponse.MonthlyUsage
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classWorkspaceUpdateResponse.MonthlyUsage.BuilderA builder for MonthlyUsage.
-
Method Summary
Modifier and Type Method Description final Optional<Long>executionTimeMs()final Optional<LocalDate>monthYear()final Optional<Long>predictionCount()final JsonField<Long>_executionTimeMs()Returns the raw JSON value of executionTimeMs. final JsonField<LocalDate>_monthYear()Returns the raw JSON value of monthYear. final JsonField<Long>_predictionCount()Returns the raw JSON value of predictionCount. final Map<String, JsonValue>_additionalProperties()final WorkspaceUpdateResponse.MonthlyUsage.BuildertoBuilder()final WorkspaceUpdateResponse.MonthlyUsagevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static WorkspaceUpdateResponse.MonthlyUsage.Builderbuilder()Returns a mutable builder for constructing an instance of MonthlyUsage. -
-
Method Detail
-
executionTimeMs
final Optional<Long> executionTimeMs()
-
predictionCount
final Optional<Long> predictionCount()
-
_executionTimeMs
final JsonField<Long> _executionTimeMs()
Returns the raw JSON value of executionTimeMs.
Unlike executionTimeMs, this method doesn't throw if the JSON field has an unexpected type.
-
_monthYear
final JsonField<LocalDate> _monthYear()
Returns the raw JSON value of monthYear.
Unlike monthYear, this method doesn't throw if the JSON field has an unexpected type.
-
_predictionCount
final JsonField<Long> _predictionCount()
Returns the raw JSON value of predictionCount.
Unlike predictionCount, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final WorkspaceUpdateResponse.MonthlyUsage.Builder toBuilder()
-
validate
final WorkspaceUpdateResponse.MonthlyUsage validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static WorkspaceUpdateResponse.MonthlyUsage.Builder builder()
Returns a mutable builder for constructing an instance of MonthlyUsage.
-
-
-
-