Class ApiKeyCreateResponse
-
- All Implemented Interfaces:
public final class ApiKeyCreateResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classApiKeyCreateResponse.BuilderA builder for ApiKeyCreateResponse.
-
Method Summary
Modifier and Type Method Description final Stringid()The API key id. final OffsetDateTimedateCreated()The API key creation date. final Optional<OffsetDateTime>dateLastUsed()The API key last use date. final OffsetDateTimedateUpdated()The API key last update date. final StringsecureKey()The API key value. final Optional<String>name()The API key name. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_dateCreated()Returns the raw JSON value of dateCreated. final JsonField<OffsetDateTime>_dateLastUsed()Returns the raw JSON value of dateLastUsed. final JsonField<OffsetDateTime>_dateUpdated()Returns the raw JSON value of dateUpdated. final JsonField<String>_secureKey()Returns the raw JSON value of secureKey. final JsonField<String>_name()Returns the raw JSON value of name. final Map<String, JsonValue>_additionalProperties()final ApiKeyCreateResponse.BuildertoBuilder()final ApiKeyCreateResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static ApiKeyCreateResponse.Builderbuilder()Returns a mutable builder for constructing an instance of ApiKeyCreateResponse. -
-
Method Detail
-
dateCreated
final OffsetDateTime dateCreated()
The API key creation date.
-
dateLastUsed
final Optional<OffsetDateTime> dateLastUsed()
The API key last use date.
-
dateUpdated
final OffsetDateTime dateUpdated()
The API key last update date.
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_dateCreated
final JsonField<OffsetDateTime> _dateCreated()
Returns the raw JSON value of dateCreated.
Unlike dateCreated, this method doesn't throw if the JSON field has an unexpected type.
-
_dateLastUsed
final JsonField<OffsetDateTime> _dateLastUsed()
Returns the raw JSON value of dateLastUsed.
Unlike dateLastUsed, this method doesn't throw if the JSON field has an unexpected type.
-
_dateUpdated
final JsonField<OffsetDateTime> _dateUpdated()
Returns the raw JSON value of dateUpdated.
Unlike dateUpdated, this method doesn't throw if the JSON field has an unexpected type.
-
_secureKey
final JsonField<String> _secureKey()
Returns the raw JSON value of secureKey.
Unlike secureKey, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final ApiKeyCreateResponse.Builder toBuilder()
-
validate
final ApiKeyCreateResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static ApiKeyCreateResponse.Builder builder()
Returns a mutable builder for constructing an instance of ApiKeyCreateResponse.
The following fields are required:
.id() .dateCreated() .dateLastUsed() .dateUpdated() .secureKey()
-
-
-
-