Class InviteCreateParams.Body
-
- All Implemented Interfaces:
public final class InviteCreateParams.Body
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInviteCreateParams.Body.BuilderA builder for Body.
-
Method Summary
Modifier and Type Method Description final Optional<List<String>>emails()final Optional<InviteCreateParams.Role>role()The member role. final JsonField<List<String>>_emails()Returns the raw JSON value of emails. final JsonField<InviteCreateParams.Role>_role()Returns the raw JSON value of role. final Map<String, JsonValue>_additionalProperties()final InviteCreateParams.Body.BuildertoBuilder()final InviteCreateParams.Bodyvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InviteCreateParams.Body.Builderbuilder()Returns a mutable builder for constructing an instance of Body. -
-
Method Detail
-
role
final Optional<InviteCreateParams.Role> role()
The member role.
-
_emails
final JsonField<List<String>> _emails()
Returns the raw JSON value of emails.
Unlike emails, this method doesn't throw if the JSON field has an unexpected type.
-
_role
final JsonField<InviteCreateParams.Role> _role()
Returns the raw JSON value of role.
Unlike role, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InviteCreateParams.Body.Builder toBuilder()
-
validate
final InviteCreateParams.Body validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InviteCreateParams.Body.Builder builder()
Returns a mutable builder for constructing an instance of Body.
-
-
-
-