Class InviteCreateResponse.Item
-
- All Implemented Interfaces:
public final class InviteCreateResponse.Item
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInviteCreateResponse.Item.BuilderA builder for Item.
public final classInviteCreateResponse.Item.Creatorpublic final classInviteCreateResponse.Item.RoleThe invite role.
public final classInviteCreateResponse.Item.StatusThe invite status.
public final classInviteCreateResponse.Item.Workspace
-
Method Summary
Modifier and Type Method Description final Stringid()The invite id. final InviteCreateResponse.Item.Creatorcreator()final OffsetDateTimedateCreated()The invite creation date. final Stringemail()The invite email. final InviteCreateResponse.Item.Rolerole()The invite role. final InviteCreateResponse.Item.Statusstatus()The invite status. final InviteCreateResponse.Item.Workspaceworkspace()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<InviteCreateResponse.Item.Creator>_creator()Returns the raw JSON value of creator. final JsonField<OffsetDateTime>_dateCreated()Returns the raw JSON value of dateCreated. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<InviteCreateResponse.Item.Role>_role()Returns the raw JSON value of role. final JsonField<InviteCreateResponse.Item.Status>_status()Returns the raw JSON value of status. final JsonField<InviteCreateResponse.Item.Workspace>_workspace()Returns the raw JSON value of workspace. final Map<String, JsonValue>_additionalProperties()final InviteCreateResponse.Item.BuildertoBuilder()final InviteCreateResponse.Itemvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InviteCreateResponse.Item.Builderbuilder()Returns a mutable builder for constructing an instance of Item. -
-
Method Detail
-
creator
final InviteCreateResponse.Item.Creator creator()
-
dateCreated
final OffsetDateTime dateCreated()
The invite creation date.
-
role
final InviteCreateResponse.Item.Role role()
The invite role.
-
status
final InviteCreateResponse.Item.Status status()
The invite status.
-
workspace
final InviteCreateResponse.Item.Workspace workspace()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_creator
final JsonField<InviteCreateResponse.Item.Creator> _creator()
Returns the raw JSON value of creator.
Unlike creator, this method doesn't throw if the JSON field has an unexpected type.
-
_dateCreated
final JsonField<OffsetDateTime> _dateCreated()
Returns the raw JSON value of dateCreated.
Unlike dateCreated, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_role
final JsonField<InviteCreateResponse.Item.Role> _role()
Returns the raw JSON value of role.
Unlike role, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<InviteCreateResponse.Item.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_workspace
final JsonField<InviteCreateResponse.Item.Workspace> _workspace()
Returns the raw JSON value of workspace.
Unlike workspace, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InviteCreateResponse.Item.Builder toBuilder()
-
validate
final InviteCreateResponse.Item validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InviteCreateResponse.Item.Builder builder()
Returns a mutable builder for constructing an instance of Item.
The following fields are required:
.id() .creator() .dateCreated() .email() .role() .status() .workspace()
-
-
-
-