Class InviteCreateResponse.Item.Creator
-
- All Implemented Interfaces:
public final class InviteCreateResponse.Item.Creator
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInviteCreateResponse.Item.Creator.BuilderA builder for Creator.
-
Method Summary
Modifier and Type Method Description final Optional<String>id()The invite creator id. final Optional<String>name()The invite creator name. final Optional<String>username()The invite creator username. final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_username()Returns the raw JSON value of username. final Map<String, JsonValue>_additionalProperties()final InviteCreateResponse.Item.Creator.BuildertoBuilder()final InviteCreateResponse.Item.Creatorvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InviteCreateResponse.Item.Creator.Builderbuilder()Returns a mutable builder for constructing an instance of Creator. -
-
Method Detail
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_username
final JsonField<String> _username()
Returns the raw JSON value of username.
Unlike username, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InviteCreateResponse.Item.Creator.Builder toBuilder()
-
validate
final InviteCreateResponse.Item.Creator validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InviteCreateResponse.Item.Creator.Builder builder()
Returns a mutable builder for constructing an instance of Creator.
-
-
-
-