Class InviteCreateResponse.Item.Workspace
-
- All Implemented Interfaces:
public final class InviteCreateResponse.Item.Workspace
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInviteCreateResponse.Item.Workspace.BuilderA builder for Workspace.
-
Method Summary
Modifier and Type Method Description final Stringid()final OffsetDateTimedateCreated()final LongmemberCount()final Stringname()final Stringslug()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<OffsetDateTime>_dateCreated()Returns the raw JSON value of dateCreated. final JsonField<Long>_memberCount()Returns the raw JSON value of memberCount. final JsonField<String>_name()Returns the raw JSON value of name. final JsonField<String>_slug()Returns the raw JSON value of slug. final Map<String, JsonValue>_additionalProperties()final InviteCreateResponse.Item.Workspace.BuildertoBuilder()final InviteCreateResponse.Item.Workspacevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InviteCreateResponse.Item.Workspace.Builderbuilder()Returns a mutable builder for constructing an instance of Workspace. -
-
Method Detail
-
dateCreated
final OffsetDateTime dateCreated()
-
memberCount
final Long memberCount()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_dateCreated
final JsonField<OffsetDateTime> _dateCreated()
Returns the raw JSON value of dateCreated.
Unlike dateCreated, this method doesn't throw if the JSON field has an unexpected type.
-
_memberCount
final JsonField<Long> _memberCount()
Returns the raw JSON value of memberCount.
Unlike memberCount, this method doesn't throw if the JSON field has an unexpected type.
-
_name
final JsonField<String> _name()
Returns the raw JSON value of name.
Unlike name, this method doesn't throw if the JSON field has an unexpected type.
-
_slug
final JsonField<String> _slug()
Returns the raw JSON value of slug.
Unlike slug, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InviteCreateResponse.Item.Workspace.Builder toBuilder()
-
validate
final InviteCreateResponse.Item.Workspace validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InviteCreateResponse.Item.Workspace.Builder builder()
Returns a mutable builder for constructing an instance of Workspace.
The following fields are required:
.id() .dateCreated() .memberCount() .name() .slug()
-
-
-
-