Class InviteListResponse
-
- All Implemented Interfaces:
public final class InviteListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInviteListResponse.BuilderA builder for InviteListResponse.
public final classInviteListResponse.Item
-
Method Summary
Modifier and Type Method Description final List<InviteListResponse.Item>items()final JsonField<List<InviteListResponse.Item>>_items()Returns the raw JSON value of items. final Map<String, JsonValue>_additionalProperties()final InviteListResponse.BuildertoBuilder()final InviteListResponsevalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InviteListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of InviteListResponse. -
-
Method Detail
-
items
final List<InviteListResponse.Item> items()
-
_items
final JsonField<List<InviteListResponse.Item>> _items()
Returns the raw JSON value of items.
Unlike items, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InviteListResponse.Builder toBuilder()
-
validate
final InviteListResponse validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InviteListResponse.Builder builder()
Returns a mutable builder for constructing an instance of InviteListResponse.
The following fields are required:
.items()
-
-
-
-