Class InviteListResponse.Item
-
- All Implemented Interfaces:
public final class InviteListResponse.Item
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInviteListResponse.Item.BuilderA builder for Item.
public final classInviteListResponse.Item.Creatorpublic final classInviteListResponse.Item.RoleThe invite role.
public final classInviteListResponse.Item.StatusThe invite status.
public final classInviteListResponse.Item.Workspace
-
Method Summary
Modifier and Type Method Description final Stringid()The invite id. final InviteListResponse.Item.Creatorcreator()final OffsetDateTimedateCreated()The invite creation date. final Stringemail()The invite email. final InviteListResponse.Item.Rolerole()The invite role. final InviteListResponse.Item.Statusstatus()The invite status. final InviteListResponse.Item.Workspaceworkspace()final JsonField<String>_id()Returns the raw JSON value of id. final JsonField<InviteListResponse.Item.Creator>_creator()Returns the raw JSON value of creator. final JsonField<OffsetDateTime>_dateCreated()Returns the raw JSON value of dateCreated. final JsonField<String>_email()Returns the raw JSON value of email. final JsonField<InviteListResponse.Item.Role>_role()Returns the raw JSON value of role. final JsonField<InviteListResponse.Item.Status>_status()Returns the raw JSON value of status. final JsonField<InviteListResponse.Item.Workspace>_workspace()Returns the raw JSON value of workspace. final Map<String, JsonValue>_additionalProperties()final InviteListResponse.Item.BuildertoBuilder()final InviteListResponse.Itemvalidate()Validates that the types of all values in this object match their expected types recursively. final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InviteListResponse.Item.Builderbuilder()Returns a mutable builder for constructing an instance of Item. -
-
Method Detail
-
creator
final InviteListResponse.Item.Creator creator()
-
dateCreated
final OffsetDateTime dateCreated()
The invite creation date.
-
role
final InviteListResponse.Item.Role role()
The invite role.
-
status
final InviteListResponse.Item.Status status()
The invite status.
-
workspace
final InviteListResponse.Item.Workspace workspace()
-
_id
final JsonField<String> _id()
Returns the raw JSON value of id.
Unlike id, this method doesn't throw if the JSON field has an unexpected type.
-
_creator
final JsonField<InviteListResponse.Item.Creator> _creator()
Returns the raw JSON value of creator.
Unlike creator, this method doesn't throw if the JSON field has an unexpected type.
-
_dateCreated
final JsonField<OffsetDateTime> _dateCreated()
Returns the raw JSON value of dateCreated.
Unlike dateCreated, this method doesn't throw if the JSON field has an unexpected type.
-
_email
final JsonField<String> _email()
Returns the raw JSON value of email.
Unlike email, this method doesn't throw if the JSON field has an unexpected type.
-
_role
final JsonField<InviteListResponse.Item.Role> _role()
Returns the raw JSON value of role.
Unlike role, this method doesn't throw if the JSON field has an unexpected type.
-
_status
final JsonField<InviteListResponse.Item.Status> _status()
Returns the raw JSON value of status.
Unlike status, this method doesn't throw if the JSON field has an unexpected type.
-
_workspace
final JsonField<InviteListResponse.Item.Workspace> _workspace()
Returns the raw JSON value of workspace.
Unlike workspace, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InviteListResponse.Item.Builder toBuilder()
-
validate
final InviteListResponse.Item validate()
Validates that the types of all values in this object match their expected types recursively.
This method is not forwards compatible with new types from the API for existing fields.
-
builder
final static InviteListResponse.Item.Builder builder()
Returns a mutable builder for constructing an instance of Item.
The following fields are required:
.id() .creator() .dateCreated() .email() .role() .status() .workspace()
-
-
-
-