Interface RowServiceAsync
-
- All Implemented Interfaces:
public interface RowServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public interfaceRowServiceAsync.WithRawResponseA view of RowServiceAsync that provides access to raw HTTP responses for each method.
-
Method Summary
-
-
Method Detail
-
withRawResponse
abstract RowServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
abstract RowServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
CompletableFuture<RowUpdateResponse> update(String inferencePipelineId, RowUpdateParams params)
Update an inference data point in an inference pipeline.
-
update
CompletableFuture<RowUpdateResponse> update(String inferencePipelineId, RowUpdateParams params, RequestOptions requestOptions)
-
update
CompletableFuture<RowUpdateResponse> update(RowUpdateParams params)
-
update
abstract CompletableFuture<RowUpdateResponse> update(RowUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<RowListResponse> list(String inferencePipelineId)
A list of rows for an inference pipeline.
-
list
CompletableFuture<RowListResponse> list(String inferencePipelineId, RowListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<RowListResponse> list(String inferencePipelineId, RowListParams params)
-
list
abstract CompletableFuture<RowListResponse> list(RowListParams params, RequestOptions requestOptions)
-
list
CompletableFuture<RowListResponse> list(RowListParams params)
-
list
CompletableFuture<RowListResponse> list(String inferencePipelineId, RequestOptions requestOptions)
-
-
-
-