Class RowServiceAsyncImpl
-
- All Implemented Interfaces:
-
com.openlayer.api.services.async.inferencepipelines.RowServiceAsync
public final class RowServiceAsyncImpl implements RowServiceAsync
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRowServiceAsyncImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RowServiceAsync.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RowServiceAsyncwithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<RowRetrieveResponse>retrieve(RowRetrieveParams params, RequestOptions requestOptions)CompletableFuture<RowUpdateResponse>update(RowUpdateParams params, RequestOptions requestOptions)CompletableFuture<RowListResponse>list(RowListParams params, RequestOptions requestOptions)CompletableFuture<Void>delete(RowDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class com.openlayer.api.services.async.inferencepipelines.RowServiceAsync
delete, delete, delete, list, list, list, list, list, retrieve, retrieve, retrieve, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
RowServiceAsync.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
RowServiceAsync withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<RowRetrieveResponse> retrieve(RowRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<RowUpdateResponse> update(RowUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<RowListResponse> list(RowListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<Void> delete(RowDeleteParams params, RequestOptions requestOptions)
-
-
-
-