Class RowServiceAsyncImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.openlayer.api.services.async.inferencepipelines.RowServiceAsync.WithRawResponse
public final class RowServiceAsyncImpl.WithRawResponseImpl implements RowServiceAsync.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description RowServiceAsync.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. CompletableFuture<HttpResponseFor<RowRetrieveResponse>>retrieve(RowRetrieveParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<RowUpdateResponse>>update(RowUpdateParams params, RequestOptions requestOptions)CompletableFuture<HttpResponseFor<RowListResponse>>list(RowListParams params, RequestOptions requestOptions)CompletableFuture<HttpResponse>delete(RowDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class com.openlayer.api.services.async.inferencepipelines.RowServiceAsync.WithRawResponse
delete, delete, delete, list, list, list, list, list, retrieve, retrieve, retrieve, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
RowServiceAsync.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
CompletableFuture<HttpResponseFor<RowRetrieveResponse>> retrieve(RowRetrieveParams params, RequestOptions requestOptions)
-
update
CompletableFuture<HttpResponseFor<RowUpdateResponse>> update(RowUpdateParams params, RequestOptions requestOptions)
-
list
CompletableFuture<HttpResponseFor<RowListResponse>> list(RowListParams params, RequestOptions requestOptions)
-
delete
CompletableFuture<HttpResponse> delete(RowDeleteParams params, RequestOptions requestOptions)
-
-
-
-