Class RowServiceImpl
-
- All Implemented Interfaces:
-
com.openlayer.api.services.blocking.inferencepipelines.RowService
public final class RowServiceImpl implements RowService
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRowServiceImpl.WithRawResponseImpl
-
Method Summary
Modifier and Type Method Description RowService.WithRawResponsewithRawResponse()Returns a view of this service that provides access to raw HTTP responses for each method. RowServicewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. RowRetrieveResponseretrieve(RowRetrieveParams params, RequestOptions requestOptions)RowUpdateResponseupdate(RowUpdateParams params, RequestOptions requestOptions)RowListResponselist(RowListParams params, RequestOptions requestOptions)Unitdelete(RowDeleteParams params, RequestOptions requestOptions)-
Methods inherited from class com.openlayer.api.services.blocking.inferencepipelines.RowService
delete, delete, delete, list, list, list, list, list, retrieve, retrieve, retrieve, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withRawResponse
RowService.WithRawResponse withRawResponse()
Returns a view of this service that provides access to raw HTTP responses for each method.
-
withOptions
RowService withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
retrieve
RowRetrieveResponse retrieve(RowRetrieveParams params, RequestOptions requestOptions)
-
update
RowUpdateResponse update(RowUpdateParams params, RequestOptions requestOptions)
-
list
RowListResponse list(RowListParams params, RequestOptions requestOptions)
-
delete
Unit delete(RowDeleteParams params, RequestOptions requestOptions)
-
-
-
-