Class RowServiceImpl.WithRawResponseImpl
-
- All Implemented Interfaces:
-
com.openlayer.api.services.blocking.inferencepipelines.RowService.WithRawResponse
public final class RowServiceImpl.WithRawResponseImpl implements RowService.WithRawResponse
-
-
Method Summary
Modifier and Type Method Description RowService.WithRawResponsewithOptions(Consumer<ClientOptions.Builder> modifier)Returns a view of this service with the given option modifications applied. HttpResponseFor<RowUpdateResponse>update(RowUpdateParams params, RequestOptions requestOptions)HttpResponseFor<RowListResponse>list(RowListParams params, RequestOptions requestOptions)-
Methods inherited from class com.openlayer.api.services.blocking.inferencepipelines.RowService.WithRawResponse
list, list, list, list, list, update, update, update -
Methods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait
-
-
Method Detail
-
withOptions
RowService.WithRawResponse withOptions(Consumer<ClientOptions.Builder> modifier)
Returns a view of this service with the given option modifications applied.
The original service is not modified.
-
update
HttpResponseFor<RowUpdateResponse> update(RowUpdateParams params, RequestOptions requestOptions)
-
list
HttpResponseFor<RowListResponse> list(RowListParams params, RequestOptions requestOptions)
-
-
-
-