Class InferencePipelineRetrieveSessionsParams
-
- All Implemented Interfaces:
-
com.openlayer.api.core.Params
public final class InferencePipelineRetrieveSessionsParams implements Params
Get aggregated session data for an inference pipeline with pagination and metadata.
Returns a list of sessions for the inference pipeline, including activity statistics such as record counts, token usage, cost, latency, and the first and last records.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInferencePipelineRetrieveSessionsParams.BuilderA builder for InferencePipelineRetrieveSessionsParams.
public final classInferencePipelineRetrieveSessionsParams.Bodypublic final classInferencePipelineRetrieveSessionsParams.ColumnFilter
-
Method Summary
-
-
Method Detail
-
inferencePipelineId
final Optional<String> inferencePipelineId()
-
sortColumn
final Optional<String> sortColumn()
Name of the column to sort on
-
columnFilters
final Optional<List<InferencePipelineRetrieveSessionsParams.ColumnFilter>> columnFilters()
-
excludeRowIdList
final Optional<List<Long>> excludeRowIdList()
-
notSearchQueryAnd
final Optional<List<String>> notSearchQueryAnd()
-
notSearchQueryOr
final Optional<List<String>> notSearchQueryOr()
-
searchQueryAnd
final Optional<List<String>> searchQueryAnd()
-
searchQueryOr
final Optional<List<String>> searchQueryOr()
-
_columnFilters
final JsonField<List<InferencePipelineRetrieveSessionsParams.ColumnFilter>> _columnFilters()
Returns the raw JSON value of columnFilters.
Unlike columnFilters, this method doesn't throw if the JSON field has an unexpected type.
-
_excludeRowIdList
final JsonField<List<Long>> _excludeRowIdList()
Returns the raw JSON value of excludeRowIdList.
Unlike excludeRowIdList, this method doesn't throw if the JSON field has an unexpected type.
-
_notSearchQueryAnd
final JsonField<List<String>> _notSearchQueryAnd()
Returns the raw JSON value of notSearchQueryAnd.
Unlike notSearchQueryAnd, this method doesn't throw if the JSON field has an unexpected type.
-
_notSearchQueryOr
final JsonField<List<String>> _notSearchQueryOr()
Returns the raw JSON value of notSearchQueryOr.
Unlike notSearchQueryOr, this method doesn't throw if the JSON field has an unexpected type.
-
_rowIdList
final JsonField<List<Long>> _rowIdList()
Returns the raw JSON value of rowIdList.
Unlike rowIdList, this method doesn't throw if the JSON field has an unexpected type.
-
_searchQueryAnd
final JsonField<List<String>> _searchQueryAnd()
Returns the raw JSON value of searchQueryAnd.
Unlike searchQueryAnd, this method doesn't throw if the JSON field has an unexpected type.
-
_searchQueryOr
final JsonField<List<String>> _searchQueryOr()
Returns the raw JSON value of searchQueryOr.
Unlike searchQueryOr, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalBodyProperties
final Map<String, JsonValue> _additionalBodyProperties()
-
_additionalHeaders
final Headers _additionalHeaders()
Additional headers to send with the request.
-
_additionalQueryParams
final QueryParams _additionalQueryParams()
Additional query param to send with the request.
-
toBuilder
final InferencePipelineRetrieveSessionsParams.Builder toBuilder()
-
_body
final InferencePipelineRetrieveSessionsParams.Body _body()
-
_pathParam
final String _pathParam(Integer index)
-
_headers
Headers _headers()
The full set of headers in the parameters, including both fixed and additional headers.
-
_queryParams
QueryParams _queryParams()
The full set of query params in the parameters, including both fixed and additional query params.
-
none
final static InferencePipelineRetrieveSessionsParams none()
-
builder
final static InferencePipelineRetrieveSessionsParams.Builder builder()
Returns a mutable builder for constructing an instance of InferencePipelineRetrieveSessionsParams.
-
-
-
-