Class RowListResponse.Item
-
- All Implemented Interfaces:
public final class RowListResponse.Item
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRowListResponse.Item.BuilderA builder for Item.
-
Method Summary
Modifier and Type Method Description final LongopenlayerRowId()final JsonField<Long>_openlayerRowId()Returns the raw JSON value of openlayerRowId. final Map<String, JsonValue>_additionalProperties()final RowListResponse.Item.BuildertoBuilder()final RowListResponse.Itemvalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RowListResponse.Item.Builderbuilder()Returns a mutable builder for constructing an instance of Item. -
-
Method Detail
-
openlayerRowId
final Long openlayerRowId()
-
_openlayerRowId
final JsonField<Long> _openlayerRowId()
Returns the raw JSON value of openlayerRowId.
Unlike openlayerRowId, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RowListResponse.Item.Builder toBuilder()
-
validate
final RowListResponse.Item validate()
-
builder
final static RowListResponse.Item.Builder builder()
Returns a mutable builder for constructing an instance of Item.
The following fields are required:
.openlayerRowId()
-
-
-
-