Class RowRetrieveResponse
-
- All Implemented Interfaces:
public final class RowRetrieveResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classRowRetrieveResponse.BuilderA builder for RowRetrieveResponse.
-
Method Summary
Modifier and Type Method Description final JsonValue_row()This arbitrary value can be deserialized into a custom type using the convertmethod:MyClass myObject = rowRetrieveResponse.row().convert(MyClass.class);final Optional<Boolean>success()final JsonField<Boolean>_success()Returns the raw JSON value of success. final Map<String, JsonValue>_additionalProperties()final RowRetrieveResponse.BuildertoBuilder()final RowRetrieveResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static RowRetrieveResponse.Builderbuilder()Returns a mutable builder for constructing an instance of RowRetrieveResponse. -
-
Method Detail
-
_row
final JsonValue _row()
This arbitrary value can be deserialized into a custom type using the
convertmethod:MyClass myObject = rowRetrieveResponse.row().convert(MyClass.class);
-
_success
final JsonField<Boolean> _success()
Returns the raw JSON value of success.
Unlike success, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final RowRetrieveResponse.Builder toBuilder()
-
validate
final RowRetrieveResponse validate()
-
builder
final static RowRetrieveResponse.Builder builder()
Returns a mutable builder for constructing an instance of RowRetrieveResponse.
-
-
-
-