Class InviteListResponse
-
- All Implemented Interfaces:
public final class InviteListResponse
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description public final classInviteListResponse.BuilderA builder for InviteListResponse.
public final classInviteListResponse._Metapublic final classInviteListResponse.Item
-
Method Summary
Modifier and Type Method Description final InviteListResponse._Meta_meta()final List<InviteListResponse.Item>items()final JsonField<InviteListResponse._Meta>__meta()Returns the raw JSON value of _meta. final JsonField<List<InviteListResponse.Item>>_items()Returns the raw JSON value of items. final Map<String, JsonValue>_additionalProperties()final InviteListResponse.BuildertoBuilder()final InviteListResponsevalidate()final BooleanisValid()Booleanequals(Object other)IntegerhashCode()StringtoString()final static InviteListResponse.Builderbuilder()Returns a mutable builder for constructing an instance of InviteListResponse. -
-
Method Detail
-
_meta
final InviteListResponse._Meta _meta()
-
items
final List<InviteListResponse.Item> items()
-
__meta
final JsonField<InviteListResponse._Meta> __meta()
Returns the raw JSON value of _meta.
Unlike _meta, this method doesn't throw if the JSON field has an unexpected type.
-
_items
final JsonField<List<InviteListResponse.Item>> _items()
Returns the raw JSON value of items.
Unlike items, this method doesn't throw if the JSON field has an unexpected type.
-
_additionalProperties
final Map<String, JsonValue> _additionalProperties()
-
toBuilder
final InviteListResponse.Builder toBuilder()
-
validate
final InviteListResponse validate()
-
builder
final static InviteListResponse.Builder builder()
Returns a mutable builder for constructing an instance of InviteListResponse.
The following fields are required:
._meta() .items()
-
-
-
-